@@ -59,19 +59,9 @@ hv_to_assoc_cond(HV* hv, slurmdb_assoc_cond_t* assoc_cond)
     assoc_cond->usage_start = start_time;
     assoc_cond->usage_end = end_time;
 
-    assoc_cond->with_usage = 1;
-    assoc_cond->with_deleted = 0;
-    assoc_cond->with_raw_qos = 0;
-    assoc_cond->with_sub_accts = 0;
-    assoc_cond->without_parent_info = 0;
-    assoc_cond->without_parent_limits = 0;
+    assoc_cond->flags = ASSOC_COND_FLAG_WITH_USAGE;
 
-    FETCH_FIELD(hv, assoc_cond, with_usage,            uint16_t, FALSE);
-    FETCH_FIELD(hv, assoc_cond, with_deleted,          uint16_t, FALSE);
-    FETCH_FIELD(hv, assoc_cond, with_raw_qos,          uint16_t, FALSE);
-    FETCH_FIELD(hv, assoc_cond, with_sub_accts,        uint16_t, FALSE);
-    FETCH_FIELD(hv, assoc_cond, without_parent_info,   uint16_t, FALSE);
-    FETCH_FIELD(hv, assoc_cond, without_parent_limits, uint16_t, FALSE);
+    FETCH_FIELD(hv, assoc_cond, flags, uint32_t, FALSE);
 
     FETCH_LIST_FIELD(hv, assoc_cond, acct_list);
     FETCH_LIST_FIELD(hv, assoc_cond, cluster_list);
@@ -781,7 +771,7 @@ hv_to_qos_cond(HV* hv, slurmdb_qos_cond_t* qos_cond)
     int    i, elements = 0;
 
     FETCH_FIELD(hv, qos_cond, preempt_mode, uint16_t, FALSE);
-    FETCH_FIELD(hv, qos_cond, with_deleted, uint16_t, FALSE);
+    FETCH_FIELD(hv, qos_cond, flags, uint16_t, FALSE);
 
     FETCH_LIST_FIELD(hv, qos_cond, description_list);
     FETCH_LIST_FIELD(hv, qos_cond, id_list);
