@@ -49,7 +49,7 @@
  * IN:  slurmdb_user_cond_t *user_cond
  * RET: SLURM_SUCCESS on success SLURM_ERROR else
  */
-extern int slurmdb_coord_add(void *db_conn, List acct_list,
+extern int slurmdb_coord_add(void *db_conn, list_t *acct_list,
 			     slurmdb_user_cond_t *user_cond)
 {
 	if (db_api_uid == -1)
@@ -65,8 +65,8 @@ extern int slurmdb_coord_add(void *db_conn, List acct_list,
  * IN: slurmdb_user_cond_t *user_cond
  * RET: List containing (char *'s) else NULL on error
  */
-extern List slurmdb_coord_remove(void *db_conn, List acct_list,
-				 slurmdb_user_cond_t *user_cond)
+extern list_t *slurmdb_coord_remove(void *db_conn, list_t *acct_list,
+				    slurmdb_user_cond_t *user_cond)
 {
 	if (db_api_uid == -1)
 		db_api_uid = getuid();
