@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  init.c - libslurm library initialization
  *****************************************************************************
- *  Copyright (C) 2020 SchedMD LLC
- *  Written by Tim Wickberg <tim@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -42,6 +41,7 @@
 #include "src/interfaces/gres.h"
 #include "src/interfaces/hash.h"
 #include "src/interfaces/select.h"
+#include "src/interfaces/tls.h"
 
 extern void slurm_init(const char *conf)
 {
@@ -53,6 +53,9 @@ extern void slurm_init(const char *conf)
 	if (hash_g_init() != SLURM_SUCCESS)
 		fatal("failed to initialize hash plugin");
 
+	if (tls_g_init() != SLURM_SUCCESS)
+		fatal("failed to initialize tls plugin");
+
 	if (acct_storage_g_init() != SLURM_SUCCESS)
 		fatal("failed to initialize the accounting storage plugin");
 
@@ -68,6 +71,7 @@ extern void slurm_fini(void)
 	cred_g_fini();
 	gres_fini();
 	acct_storage_g_fini();
+	tls_g_fini();
 	hash_g_fini();
 	auth_g_fini();
 
