@@ -3,7 +3,7 @@
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
- *  Portions Copyright (C) 2010-2017 SchedMD LLC <https://www.schedmd.com>.
+ *  Copyright (C) SchedMD LLC.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov> et. al.
  *  CODE-OCEC-09-009. All rights reserved.
@@ -53,7 +53,6 @@
 #include "src/interfaces/select.h"
 #include "src/interfaces/acct_gather_energy.h"
 #include "src/interfaces/auth.h"
-#include "src/interfaces/ext_sensors.h"
 #include "src/common/slurm_protocol_api.h"
 #include "src/common/slurm_resource_info.h"
 #include "src/common/uid.h"
@@ -66,7 +65,7 @@ typedef struct load_node_req_struct {
 	slurmdb_cluster_rec_t *cluster;
 	int cluster_inx;
 	slurm_msg_t *req_msg;
-	List resp_msg_list;
+	list_t *resp_msg_list;
 	uint16_t show_flags;
 } load_node_req_struct_t;
 
@@ -310,6 +309,13 @@ char *slurm_sprint_node_table(node_info_t *node_ptr, int one_liner)
 		xstrcat(out, line_end);
 	}
 
+	/* cores per gpu (optional) */
+	if (node_ptr->res_cores_per_gpu) {
+		xstrfmtcat(out, "RestrictedCoresPerGPU=%u(%s) ",
+			   node_ptr->res_cores_per_gpu, node_ptr->gpu_spec);
+		xstrcat(out, line_end);
+	}
+
 	/****** Line ******/
 	complete_state = node_state_string_complete(node_ptr->node_state);
 	xstrfmtcat(out, "State=%s ThreadsPerCore=%u TmpDisk=%u Weight=%u ",
@@ -387,14 +393,6 @@ char *slurm_sprint_node_table(node_info_t *node_ptr, int one_liner)
 	xfree(node_alloc_tres);
 	xstrcat(out, line_end);
 
-	/****** Power Management Line ******/
-	if (!node_ptr->power || (node_ptr->power->cap_watts == NO_VAL))
-		xstrcat(out, "CapWatts=n/a");
-	else
-		xstrfmtcat(out, "CapWatts=%u", node_ptr->power->cap_watts);
-
-	xstrcat(out, line_end);
-
 	/****** Power Consumption Line ******/
 	if (!node_ptr->energy || node_ptr->energy->current_watts == NO_VAL)
 		xstrcat(out, "CurrentWatts=n/a AveWatts=n/a");
@@ -405,28 +403,6 @@ char *slurm_sprint_node_table(node_info_t *node_ptr, int one_liner)
 
 	xstrcat(out, line_end);
 
-	/****** external sensors Line ******/
-	if (!node_ptr->ext_sensors
-	    || node_ptr->ext_sensors->consumed_energy == NO_VAL64)
-		xstrcat(out, "ExtSensorsJoules=n/a ");
-	else
-		xstrfmtcat(out, "ExtSensorsJoules=%"PRIu64" ",
-			   node_ptr->ext_sensors->consumed_energy);
-
-	if (!node_ptr->ext_sensors
-	    || node_ptr->ext_sensors->current_watts == NO_VAL)
-		xstrcat(out, "ExtSensorsWatts=n/a ");
-	else
-		xstrfmtcat(out, "ExtSensorsWatts=%u ",
-			   node_ptr->ext_sensors->current_watts);
-
-	if (!node_ptr->ext_sensors
-	    || node_ptr->ext_sensors->temperature == NO_VAL)
-		xstrcat(out, "ExtSensorsTemp=n/a");
-	else
-		xstrfmtcat(out, "ExtSensorsTemp=%u",
-			   node_ptr->ext_sensors->temperature);
-
 	/****** Line ******/
 	if (node_ptr->reason && node_ptr->reason[0])
 		xstrcat(reason_str, node_ptr->reason);
@@ -502,6 +478,10 @@ static void _set_node_mixed_op(node_info_t *node_ptr)
 
 	xassert(node_ptr);
 
+	/* Node is blank/hidden (e.g. blank dynamic node) */
+	if (!node_ptr->name)
+		return;
+
 	select_g_select_nodeinfo_get(node_ptr->select_nodeinfo,
 				     SELECT_NODEDATA_SUBCNT,
 				     NODE_STATE_ALLOCATED, &alloc_cpus);
@@ -627,11 +607,11 @@ static int _load_fed_nodes(slurm_msg_t *req_msg,
 	node_info_msg_t *orig_msg = NULL, *new_msg = NULL;
 	uint32_t new_rec_cnt;
 	slurmdb_cluster_rec_t *cluster;
-	ListIterator iter;
+	list_itr_t *iter;
 	int pthread_count = 0;
 	pthread_t *load_thread = 0;
 	load_node_req_struct_t *load_args;
-	List resp_msg_list;
+	list_t *resp_msg_list;
 
 	*node_info_msg_pptr = NULL;
 
@@ -659,7 +639,7 @@ static int _load_fed_nodes(slurm_msg_t *req_msg,
 
 	/* Wait for all pthreads to complete */
 	for (i = 0; i < pthread_count; i++)
-		pthread_join(load_thread[i], NULL);
+		slurm_thread_join(load_thread[i]);
 	xfree(load_thread);
 
 	/* Maintain a consistent cluster/node ordering */
