@@ -1,7 +1,7 @@
 /****************************************************************************\
  *  file_bcast.h - definitions used for file broadcast functions
  *****************************************************************************
- *  Copyright (C) 2015-2016 SchedMD LLC.
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -40,17 +40,20 @@
 #include "src/common/macros.h"
 #include "src/common/slurm_protocol_defs.h"
 
-#define BCAST_FLAG_FORCE	 0x0001
-#define BCAST_FLAG_PRESERVE	 0x0002
-#define BCAST_FLAG_SEND_LIBS	 0x0004
-#define BCAST_FLAG_SHARED_OBJECT 0x0008
+#define BCAST_FLAG_FORCE SLURM_BIT(0)
+#define BCAST_FLAG_PRESERVE SLURM_BIT(1)
+#define BCAST_FLAG_SEND_LIBS SLURM_BIT(2)
+#define BCAST_FLAG_SHARED_OBJECT SLURM_BIT(3)
+#define BCAST_FLAG_NO_JOB SLURM_BIT(4)
 
 struct bcast_parameters {
 	uint32_t block_size;
 	uint16_t compress;
 	char *exclude;
 	char *dst_fname;
+	char *exe_fname;
 	uint16_t flags;
+	char *node_list;
 	slurm_selected_step_t *selected_step;
 	char *src_fname;
 	uint32_t step_id;
@@ -77,7 +80,7 @@ typedef struct {
 	uint32_t bcast_sent_cnt;		/* succeeded bcast count */
 	int bcast_total_cnt;			/* libs in list count */
 	struct bcast_parameters *params;	/* bcast parameters */
-	List excluded_paths;			/* excluded paths list */
+	list_t *excluded_paths;			/* excluded paths list */
 	int return_code;			/* bcast_file() rc */
 } foreach_shared_object_t;
 
