@@ -2,7 +2,6 @@
  *  extra_constraints.c
  *****************************************************************************
  *  Copyright (C) SchedMD LLC.
- *  Written by Marshall Garey <marshall@schedmd.com>
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -42,7 +41,6 @@
 #include "src/common/xassert.h"
 #include "src/common/xmalloc.h"
 #include "src/common/xstring.h"
-#include "src/interfaces/serializer.h"
 
 #define _DEBUG 0 /* Set this to non-zero to see detailed debugging */
 
@@ -215,10 +213,10 @@ static op_t _str2op(char *str, const char *valid_chars, char **end_out)
 	char save_char;
 	char *end = str;
 
-	xassert(strchr(valid_chars, *str));
+	xassert(xstrchr(valid_chars, *str));
 
 	while (*end) {
-		if (!strchr(valid_chars, *end))
+		if (!xstrchr(valid_chars, *end))
 			break;
 		end++;
 	}
@@ -241,19 +239,24 @@ static op_t _str2op(char *str, const char *valid_chars, char **end_out)
 	return op;
 }
 
-static char *_find_op_in_string(char *str)
+/*
+ * Return true if the key or value is valid, false otherwise.
+ * A valid key/value is not an empty string and does not have any operator
+ * characters.
+ */
+static bool _valid_key_value(char *str)
 {
 	char *p;
 
-	if (!str)
-		return NULL;
+	if (!str || (*str == '\0'))
+		return false;
 
 	while (*str) {
-		if ((p = strchr(op_chars, *str)))
-			return p;
+		if ((p = xstrchr(op_chars, *str)))
+			return false;
 		str++;
 	}
-	return NULL;
+	return true;
 }
 
 /*
@@ -274,7 +277,7 @@ static elem_t *_parse_leaf(char *str)
 		return NULL;
 
 	/* This is not a leaf if there are paren */
-	xassert(!strchr(str, '(') && !strchr(str, ')'));
+	xassert(!xstrchr(str, '(') && !xstrchr(str, ')'));
 
 	if (*str == '\0') {
 #if _DEBUG
@@ -288,7 +291,7 @@ static elem_t *_parse_leaf(char *str)
 	/* Find the first leaf operator character */
 	op_ptr = key;
 	while (*op_ptr) {
-		if (strchr(leaf_op_chars, *op_ptr))
+		if (xstrchr(leaf_op_chars, *op_ptr))
 			break;
 		op_ptr++;
 	}
@@ -306,11 +309,11 @@ static elem_t *_parse_leaf(char *str)
 
 	if (op == OP_NONE) {
 		/*
-		 * The strchr check verified that an operator
+		 * The xstrchr check verified that an operator
 		 * character exists, but not that the whole
 		 * operator string is valid. For example, there
 		 * could be repeating operator characters:
-		 * strchr would return a pointer to the first
+		 * xstrchr would return a pointer to the first
 		 * one, but _str2op would correctly identify
 		 * that the operator is invalid.
 		 */
@@ -331,7 +334,7 @@ static elem_t *_parse_leaf(char *str)
 	*op_ptr = '\0';
 
 	/* Check for invalid characters in key and value: operators */
-	if (_find_op_in_string(key) || (_find_op_in_string(val))) {
+	if (!_valid_key_value(key) || !_valid_key_value(val)) {
 #if _DEBUG
 		error("Invalid key-op-value: %s", str);
 #endif
@@ -360,7 +363,7 @@ static char *_find_leaf_end(char *str)
 
 	/* None of the following characters are allowed in a leaf */
 	while (*ptr) {
-		if (strchr(child_op_chars, *ptr) ||
+		if (xstrchr(child_op_chars, *ptr) ||
 		    (*ptr == '(') || (*ptr == ')'))
 			break;
 		ptr++;
@@ -368,20 +371,6 @@ static char *_find_leaf_end(char *str)
 	return ptr;
 }
 
-/*
- * Make sure that all children have an operator between them.
- */
-static bool _valid_parent_child_op(elem_t *parent)
-{
-	if (parent->num_children && (parent->operator == OP_NONE)) {
-#if _DEBUG
-		error("No child operator between children");
-#endif
-		return false;
-	}
-	return true;
-}
-
 /*
  * Parse a string like the following:
  *   (a=23&(b<=42|c=foo)&d>50)&e=bar
@@ -438,23 +427,32 @@ static bool _valid_parent_child_op(elem_t *parent)
 static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 {
 	elem_t *child;
-	char *save_ptr;
+	bool got_leaf = false;
+	/* Implied operator before the first leaf on any level of the tree */
+	bool got_op = true;
 
 	xassert(str_ptr);
 	xassert(level);
 	xassert(parent);
 	xassert(rc);
 
-	/* Save a pointer to the beginning of the string */
-	save_ptr = *str_ptr;
-
-	while (**str_ptr && (*rc == SLURM_SUCCESS)) {
+	while (*rc == SLURM_SUCCESS) {
 		char save_char;
 		char *next;
 
 #if _DEBUG
 		info("level=%d, string=\"%s\"", *level, *str_ptr);
 #endif
+		if (**str_ptr == '\0') {
+			/* End of string. */
+			if (got_op || !got_leaf) {
+#if _DEBUG
+				error("Did not end in a leaf. Invalid string");
+#endif
+				*rc = SLURM_ERROR;
+			}
+			break;
+		}
 
 		/*
 		 * These first two checks go deeper or shallower in the tree.
@@ -465,7 +463,11 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 		if (**str_ptr == '(') {
 			elem_t *child;
 
-			if (!_valid_parent_child_op(parent)) {
+			if (!got_op) {
+#if _DEBUG
+				error("No boolean operator before leaf. Invalid string: \"%s\"",
+				      *str_ptr);
+#endif
 				*rc = SLURM_ERROR;
 				break;
 			}
@@ -476,6 +478,14 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 			*level = *level + 1;
 			(*str_ptr) = *str_ptr + 1;
 			_recurse(str_ptr, level, child, rc);
+			/*
+			 * Returned after a ')' is found.
+			 * Treat the contents within the parentheses as a leaf
+			 * since we expect an operator to come after the
+			 * closing paren.
+			 */
+			got_leaf = true;
+			got_op = false;
 			continue;
 		} else if (**str_ptr == ')') {
 			(*str_ptr) = *str_ptr + 1;
@@ -486,10 +496,15 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 				error("Unbalanced parentheses");
 #endif
 				*rc = SLURM_ERROR;
+				/*
+				 * Do not return because we were not recursively
+				 * called to get here.
+				 */
+				break;
 			}
-			if (!parent->num_children) {
+			if (got_op || !got_leaf) {
 #if _DEBUG
-				error("No children at this level");
+				error("Invalid expression inside parentheses, did not end in leaf");
 #endif
 				*rc = SLURM_ERROR;
 			}
@@ -498,23 +513,28 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 		}
 
 		/* Check if we are at a child operator. */
-		if (**str_ptr == '\0') {
-			/*
-			 * End of string. strchr will find the '\0' character
-			 * in a string, so we need to avoid that when looking
-			 * for child operator characters.
-			 */
-		} else if (strchr(child_op_chars, **str_ptr)) {
+		if (xstrchr(child_op_chars, **str_ptr)) {
 			char *tmp_end = NULL;
-			op_t op = _str2op(*str_ptr, child_op_chars, &tmp_end);
+			op_t op;
+
+			if (!got_leaf) {
+#if _DEBUG
+				error("Got boolean operator without a leaf. Invalid string: \"%s\"",
+				      *str_ptr);
+#endif
+				*rc = SLURM_ERROR;
+				break;
+			}
+
+			op = _str2op(*str_ptr, child_op_chars, &tmp_end);
 
 			if (op == OP_NONE) {
 				/*
-				 * The strchr check verified that an operator
+				 * The xstrchr check verified that an operator
 				 * character exists, but not that the whole
 				 * operator string is valid. For example, there
 				 * could be repeating operator characters:
-				 * strchr would return a pointer to the first
+				 * xstrchr would return a pointer to the first
 				 * one, but _str2op would correctly identify
 				 * that the operator is invalid.
 				 */
@@ -543,10 +563,16 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 				parent->operator = op;
 			}
 			*str_ptr = tmp_end;
+			got_op = true;
+			got_leaf = false;
 			continue;
 		}
 
-		if (!_valid_parent_child_op(parent)) {
+		if (!got_op) {
+#if _DEBUG
+			error("No boolean operator before leaf. Invalid string: \"%s\"",
+			      *str_ptr);
+#endif
 			*rc = SLURM_ERROR;
 			break;
 		}
@@ -572,6 +598,8 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 
 		*next = save_char;
 		*str_ptr = next;
+		got_op = false;
+		got_leaf = true;
 	}
 
 	/*
@@ -580,12 +608,6 @@ static void _recurse(char **str_ptr, int *level, elem_t *parent, int *rc)
 	 */
 	xassert(*level >= 0);
 
-	/*
-	 * Restore the pointer to the beginning so it can be free'd by the
-	 * caller if it was malloc'd.
-	 */
-	*str_ptr = save_ptr;
-
 	if (*level) {
 		/* Unbalanced parentheses or parsing error */
 #if _DEBUG
@@ -817,7 +839,7 @@ extern int extra_constraints_parse(char *extra, elem_t **head)
 {
 	int rc = SLURM_SUCCESS;
 	int level = 0;
-	char *copy;
+	char *copy, *copy_start;
 	elem_t *tree_head;
 
 	xassert(head);
@@ -834,10 +856,10 @@ extern int extra_constraints_parse(char *extra, elem_t **head)
 	copy = xstrdup(extra);
 	tree_head = _alloc_tree();
 	/*
-	 * _recurse is currently not destructive of the string.
-	 * However, just in case this changes in the future, operate on a copy
-	 * of the string.
+	 * _recurse modifies the string pointer, so save a copy of the pointer
+	 * to the beginning of the string so it can be free'd.
 	 */
+	copy_start = copy; /* Save a pointer to the beginning of the string */
 	_recurse(&copy, &level, tree_head, &rc);
 	if (rc != SLURM_SUCCESS) {
 		error("%s: Parsing %s failed", __func__, extra);
@@ -868,7 +890,7 @@ extern int extra_constraints_parse(char *extra, elem_t **head)
 #endif
 
 	*head = tree_head;
-	xfree(copy);
+	xfree(copy_start);
 	return rc;
 }
 
