@@ -50,6 +50,8 @@
 #include "src/common/log.h"	/* for error() */
 #include "src/common/strlcpy.h"
 
+#define STACK_SIZE (1024 * 1024)
+
 #ifndef MAX
 #  define MAX(a,b) ((a) > (b) ? (a) : (b))
 #endif
@@ -86,6 +88,11 @@
 # define NTOH_int64(x)	  ((int64_t)  (x))
 # define HTON_uint64(x)	  ((uint64_t) (x))
 # define NTOH_uint64(x)	  ((uint64_t) (x))
+#elif HAVE___BUILTIN_BSWAP64
+# define HTON_int64(x) ((int64_t) __builtin_bswap64(x))
+# define NTOH_int64(x) ((int64_t) __builtin_bswap64(x))
+# define HTON_uint64(x) (__builtin_bswap64(x))
+# define NTOH_uint64(x) (__builtin_bswap64(x))
 #else
 # define HTON_int64(x)    ((int64_t) UINT64_SWAP_LE_BE (x))
 # define NTOH_int64(x)	  ((int64_t) UINT64_SWAP_LE_BE (x))
@@ -98,19 +105,18 @@
 		int err = pthread_cond_init(cond, cont_attr);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_cond_init(): %m",	\
-				__FILE__, __LINE__, __func__);		\
-			abort();					\
+			fatal_abort("%s: pthread_cond_init(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
-#define slurm_cond_signal(cond)					\
+#define slurm_cond_signal(cond)						\
 	do {								\
 		int err = pthread_cond_signal(cond);			\
 		if (err) {						\
 			errno = err;					\
 			error("%s:%d %s: pthread_cond_signal(): %m",	\
-				__FILE__, __LINE__, __func__);		\
+			      __FILE__, __LINE__, __func__);		\
 		}							\
 	} while (0)
 
@@ -120,7 +126,7 @@
 		if (err) {						\
 			errno = err;					\
 			error("%s:%d %s: pthread_cond_broadcast(): %m",	\
-				__FILE__, __LINE__, __func__);		\
+			      __FILE__, __LINE__, __func__);		\
 		}							\
 	} while (0)
 
@@ -130,7 +136,7 @@
 		if (err) {						\
 			errno = err;					\
 			error("%s:%d %s: pthread_cond_wait(): %m",	\
-				__FILE__, __LINE__, __func__);		\
+			      __FILE__, __LINE__, __func__);		\
 		}							\
 	} while (0)
 
@@ -152,7 +158,7 @@
 		if (err) {						\
 			errno = err;					\
 			error("%s:%d %s: pthread_cond_destroy(): %m",	\
-				__FILE__, __LINE__, __func__);		\
+			      __FILE__, __LINE__, __func__);		\
 		}							\
 	} while (0)
 
@@ -162,9 +168,8 @@
 		int err = pthread_mutex_init(mutex, NULL);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_mutex_init(): %m",	\
-				__FILE__, __LINE__, __func__);		\
-			abort();					\
+			fatal_abort("%s: pthread_mutex_init(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -173,20 +178,18 @@
 		int err = pthread_mutex_destroy(mutex);			\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_mutex_destroy(): %m",	\
-				__FILE__, __LINE__, __func__);		\
-			abort();					\
+			fatal_abort("%s: pthread_mutex_destroy(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
-#define slurm_mutex_lock(mutex)					\
+#define slurm_mutex_lock(mutex)						\
 	do {								\
 		int err = pthread_mutex_lock(mutex);			\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_mutex_lock(): %m",	\
-				__FILE__, __LINE__, __func__);		\
-			abort();					\
+			fatal_abort("%s: pthread_mutex_lock(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -195,9 +198,8 @@
 		int err = pthread_mutex_unlock(mutex);			\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_mutex_unlock(): %m",	\
-				__FILE__, __LINE__, __func__);		\
-			abort();					\
+			fatal_abort("%s: pthread_mutex_unlock(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -206,8 +208,8 @@
 		int err = pthread_rwlock_init(rwlock, NULL);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_rwlock_init(): %m",	\
-			      __FILE__, __LINE__, __func__);		\
+			fatal_abort("%s: pthread_rwlock_init(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -216,8 +218,8 @@
 		int err = pthread_rwlock_destroy(rwlock);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_rwlock_destroy(): %m",	\
-			      __FILE__, __LINE__, __func__);		\
+			fatal_abort("%s: pthread_rwlock_destroy(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -226,8 +228,8 @@
 		int err = pthread_rwlock_rdlock(rwlock);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_rwlock_rdlock(): %m",	\
-			      __FILE__, __LINE__, __func__);		\
+			fatal_abort("%s: pthread_rwlock_rdlock(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -236,8 +238,8 @@
 		int err = pthread_rwlock_wrlock(rwlock);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_rwlock_wrlock(): %m",	\
-			      __FILE__, __LINE__, __func__);		\
+			fatal_abort("%s: pthread_rwlock_wrlock(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -246,8 +248,8 @@
 		int err = pthread_rwlock_unlock(rwlock);		\
 		if (err) {						\
 			errno = err;					\
-			fatal("%s:%d %s: pthread_rwlock_unlock(): %m",	\
-			      __FILE__, __LINE__, __func__);		\
+			fatal_abort("%s: pthread_rwlock_unlock(): %m",	\
+				    __func__);				\
 		}							\
 	} while (0)
 
@@ -268,12 +270,12 @@
 			errno = err;					\
 			error("pthread_attr_setscope: %m");		\
 		}							\
-		err = pthread_attr_setstacksize(attr, 1024*1024);	\
+		err = pthread_attr_setstacksize(attr, STACK_SIZE);	\
 		if (err) {						\
 			errno = err;					\
 			error("pthread_attr_setstacksize: %m");		\
 		}							\
-	 } while (0)
+	} while (0)
 #else
 #  define slurm_attr_init(attr)						\
 	do {								\
@@ -282,7 +284,7 @@
 			errno = err;					\
 			fatal("pthread_attr_init: %m");			\
 		}							\
-		err = pthread_attr_setstacksize(attr, 1024*1024);	\
+		err = pthread_attr_setstacksize(attr, STACK_SIZE);	\
 		if (err) {						\
 			errno = err;					\
 			error("pthread_attr_setstacksize: %m");		\
@@ -296,7 +298,7 @@
 		if (err) {						\
 			errno = err;					\
 			error("pthread_attr_destroy failed, "		\
-				"possible memory leak!: %m");		\
+			      "possible memory leak!: %m");		\
 		}							\
 	} while (0)
 
@@ -343,6 +345,21 @@
 		slurm_attr_destroy(&attr);				\
 	} while (0)
 
+/*
+ * The retval argument is intentionally omitted. We never use it.
+ */
+#define slurm_thread_join(id)						\
+	do {								\
+		int err = 0;						\
+		if (id) {						\
+			err = pthread_join(id, NULL);			\
+			id = (pthread_t) 0;				\
+		}							\
+		if (err) {						\
+			errno = err;					\
+			error("%s: pthread_join(): %m", __func__);	\
+		}							\
+	} while (0)
 
 #define slurm_atoul(str) strtoul(str, NULL, 10)
 #define slurm_atoull(str) strtoull(str, NULL, 10)
@@ -365,9 +382,15 @@
 #define FUZZY_EPSILON 0.00001
 #define fuzzy_equal(v1, v2) ((((v1)-(v2)) > -FUZZY_EPSILON) && (((v1)-(v2)) < FUZZY_EPSILON))
 
-/* Number of elements in an array */
+/* Number of elements in a static array */
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 
+/* Number of elements in an allocated array */
+#define PTR_ARRAY_SIZE(x) (xsize(x) / sizeof((x)[0]))
+
+/* Get __typeof__(s->f) */
+#define STRUCT_FIELD_TYPEOF(s, f) __typeof__(((s *) (NULL))->f)
+
 #define SWAP(x, y)		\
 do {				\
 	__typeof__(x) b = x;	\
@@ -379,4 +402,9 @@ do {				\
 #define XSTRINGIFY(s) XSTRINGIFY2(s)
 #define XSTRINGIFY2(s) #s
 
+/* Macro to stringify bool for logging */
+#define BOOL_CHARIFY(s) ((s) ? 'T' : 'F')
+/* Macro to stringify bool for logging */
+#define BOOL_STRINGIFY(s) ((s) ? "True" : "False")
+
 #endif /* !_MACROS_H */
