@@ -508,6 +508,14 @@ static void _expand_wildcard(char **expanded, char **pos, char *ptr,
 {
 	switch (*ptr) {
 	case 'A': /* Array job ID */
+		if (job->array_job_id) {
+			xstrfmtcatat(*expanded, pos, "%0*u", padding,
+				     job->array_job_id);
+		} else {
+			xstrfmtcatat(*expanded, pos, "%0*u", padding,
+				     job->jobid);
+		}
+		break;
 	case 'J': /* Jobid.stepid */
 	case 'j': /* Job ID */
 		xstrfmtcatat(*expanded, pos, "%0*u", padding, job->jobid);
@@ -605,24 +613,48 @@ extern char *expand_stdio_fields(char *stdio_path, job_std_pattern_t *job)
 				xstrfmtcatat(expanded, &pos, "%c", *ptr);
 			break;
 		case STATE_EXPAND:
+			/* Double %% is escape, so print one %. */
+			if (*ptr == '%') {
+				xstrfmtcatat(expanded, &pos, "%c", *ptr);
+				curr_state = STATE_INIT;
+				break;
+			}
 			if (isdigit(*ptr)) {
+				char *tmp_ptr = ptr;
 				if ((padding = strtoul(ptr, &end, 10)) > 9) {
 					/* Remove % and double digit 10 */
 					ptr = end;
 					padding = 10;
-				} else
+				} else {
 					ptr++;
+				}
+				/*
+				 * weird behavior fix: we remove all the digits
+				 * except the last one to match with the current
+				 * fname creation.
+				 */
+				if (!_is_wildcard(ptr)) {
+					ptr = tmp_ptr;
+					/* seek until the last digit */
+					while (isdigit(*(ptr + 1))) {
+						ptr++;
+					}
+					xstrfmtcatat(expanded, &pos,
+						     "%c", *ptr);
+					padding = 0;
+					curr_state = STATE_INIT;
+					break;
+				}
 			}
 			if (!_is_wildcard(ptr)) {
-				padding = 0;
-				xstrfmtcatat(expanded, &pos, "%c", *ptr);
+				/* If not a wildcard print also the %. */
+				xstrfmtcatat(expanded, &pos, "%%%c", *ptr);
 			} else {
 				_expand_wildcard(&expanded, &pos, ptr, padding,
 						 job);
+				padding = 0;
 			}
-			/* If we find another %, don't leave this state yet. */
-			if (*ptr != '%')
-				curr_state = STATE_INIT;
+			curr_state = STATE_INIT;
 			break;
 		default:
 			break;
