@@ -42,9 +42,6 @@
 
 #include "config.h"
 
-/* for sendto and recvfrom commands */
-#define SLURM_PROTOCOL_NO_SEND_RECV_FLAGS 0
-
 /* for listen API */
 #define SLURM_DEFAULT_LISTEN_BACKLOG 4096
 
@@ -61,17 +58,20 @@
  * done here with them since we have to support old version of archive
  * files since they don't update once they are created.
  */
+#define SLURM_24_11_PROTOCOL_VERSION ((42 << 8) | 0)
+#define SLURM_24_05_PROTOCOL_VERSION ((41 << 8) | 0)
 #define SLURM_23_11_PROTOCOL_VERSION ((40 << 8) | 0)
 #define SLURM_23_02_PROTOCOL_VERSION ((39 << 8) | 0)
-#define SLURM_22_05_PROTOCOL_VERSION ((38 << 8) | 0)
 
-#define SLURM_PROTOCOL_VERSION SLURM_23_11_PROTOCOL_VERSION
-#define SLURM_ONE_BACK_PROTOCOL_VERSION SLURM_23_02_PROTOCOL_VERSION
-#define SLURM_MIN_PROTOCOL_VERSION SLURM_22_05_PROTOCOL_VERSION
+#define SLURM_PROTOCOL_VERSION SLURM_24_11_PROTOCOL_VERSION
+#define SLURM_ONE_BACK_PROTOCOL_VERSION SLURM_24_05_PROTOCOL_VERSION
+#define SLURM_TWO_BACK_PROTOCOL_VERSION SLURM_23_11_PROTOCOL_VERSION
+#define SLURM_MIN_PROTOCOL_VERSION SLURM_23_02_PROTOCOL_VERSION
 
 #if 0
 /* Old Slurm versions kept for reference only.  Slurm only actively keeps track
  * of 2 previous versions. */
+#define SLURM_22_05_PROTOCOL_VERSION ((38 << 8) | 0)
 #define SLURM_21_08_PROTOCOL_VERSION ((37 << 8) | 0)
 #define SLURM_20_11_PROTOCOL_VERSION ((36 << 8) | 0)
 #define SLURM_20_02_PROTOCOL_VERSION ((35 << 8) | 0)
@@ -100,7 +100,7 @@
 #define SLURM_GLOBAL_AUTH_KEY   SLURM_BIT(0)
 #define SLURMDBD_CONNECTION     SLURM_BIT(1)
 #define SLURM_MSG_KEEP_BUFFER   SLURM_BIT(2)
-#define SLURM_DROP_PRIV		SLURM_BIT(3)
+/* was  SLURM_DROP_PRIV		SLURM_BIT(3) */
 #define USE_BCAST_NETWORK	SLURM_BIT(4)
 #define CTLD_QUEUE_PROCESSING	SLURM_BIT(5)
 #define SLURM_NO_AUTH_CRED	SLURM_BIT(6)
