@@ -50,7 +50,6 @@
 #include "src/common/bitstring.h"
 #include "src/common/group_cache.h"
 #include "src/common/identity.h"
-#include "src/common/io_hdr.h"
 #include "src/common/job_resources.h"
 #include "src/common/list.h"
 #include "src/common/log.h"
@@ -66,6 +65,7 @@
 #include "src/common/xstring.h"
 #include "src/interfaces/cred.h"
 #include "src/interfaces/gres.h"
+#include "src/interfaces/switch.h"
 
 typedef struct {
 	slurm_cred_t *(*cred_create)	(slurm_cred_arg_t *cred_arg,
@@ -284,6 +284,8 @@ extern void slurm_cred_free_args(slurm_cred_arg_t *arg)
 	xfree(arg->step_mem_alloc);
 	xfree(arg->step_mem_alloc_rep_count);
 
+	switch_g_free_stepinfo(arg->switch_step);
+
 	xfree(arg);
 }
 
@@ -360,12 +362,12 @@ extern slurm_cred_arg_t *slurm_cred_verify(slurm_cred_t *cred)
 	/* NOTE: the verification checks that the credential was
 	 * created by SlurmUser or root */
 	if (!cred->verified) {
-		slurm_seterrno(ESLURMD_INVALID_JOB_CREDENTIAL);
+		errno = ESLURMD_INVALID_JOB_CREDENTIAL;
 		goto error;
 	}
 
 	if (now > (cred->ctime + cred_expire)) {
-		slurm_seterrno(ESLURMD_CREDENTIAL_EXPIRED);
+		errno = ESLURMD_CREDENTIAL_EXPIRED;
 		goto error;
 	}
 
@@ -373,9 +375,9 @@ extern slurm_cred_arg_t *slurm_cred_verify(slurm_cred_t *cred)
 	return cred->arg;
 
 error:
-	errnum = slurm_get_errno();
+	errnum = errno;
 	slurm_rwlock_unlock(&cred->mutex);
-	slurm_seterrno(errnum);
+	errno = errnum;
 	return NULL;
 }
 
