@@ -92,7 +92,7 @@ struct jobacctinfo {
 	uint32_t current_weighted_power;
 	uint32_t tres_count; /* count of tres in the usage array's */
 	uint32_t *tres_ids; /* array of tres_count of the tres id's */
-	List tres_list; /* list of tres we are dealing with */
+	list_t *tres_list; /* list of tres we are dealing with */
 	uint64_t *tres_usage_in_max; /* tres max usage in data */
 	uint64_t *tres_usage_in_max_nodeid; /* tres max usage in data node id */
 	uint64_t *tres_usage_in_max_taskid; /* tres max usage in data task id */
