@@ -161,7 +161,7 @@ extern int jobcomp_g_write(job_record_t *job_ptr)
 {
 	int retval = SLURM_SUCCESS;
 
-	xassert(plugin_inited);
+	xassert(plugin_inited != PLUGIN_NOT_INITED);
 
 	if (plugin_inited == PLUGIN_NOOP)
 		return SLURM_SUCCESS;
@@ -175,11 +175,11 @@ extern int jobcomp_g_write(job_record_t *job_ptr)
 	return retval;
 }
 
-extern List jobcomp_g_get_jobs(slurmdb_job_cond_t *job_cond)
+extern list_t *jobcomp_g_get_jobs(slurmdb_job_cond_t *job_cond)
 {
-	List job_list = NULL;
+	list_t *job_list = NULL;
 
-	xassert(plugin_inited);
+	xassert(plugin_inited != PLUGIN_NOT_INITED);
 
 	if (plugin_inited == PLUGIN_NOOP)
 		return NULL;
@@ -195,7 +195,7 @@ extern int jobcomp_g_set_location(void)
 {
 	int retval = SLURM_SUCCESS;
 
-	xassert(plugin_inited);
+	xassert(plugin_inited != PLUGIN_NOT_INITED);
 
 	if (plugin_inited == PLUGIN_NOOP)
 		return SLURM_SUCCESS;
