@@ -48,13 +48,80 @@
 #include "src/common/xstring.h"
 #include "src/slurmctld/slurmctld.h"
 
-/*
- * Must be synchronized with slurm_select_ops_t in select.h.
- * Also must be synchronized with the other_select.c in
- * the select/other lib. (We tried to make it so we only had to
- * define it once, but it didn't seem to work.)
- */
-const char *node_select_syms[] = {
+typedef struct {
+	uint32_t	(*plugin_id);
+	int		(*state_save)		(char *dir_name);
+	int		(*state_restore)	(char *dir_name);
+	int		(*job_init)		(list_t *job_list);
+	int		(*node_init)		(void);
+	int		(*job_test)		(job_record_t *job_ptr,
+						 bitstr_t *bitmap,
+						 uint32_t min_nodes,
+						 uint32_t max_nodes,
+						 uint32_t req_nodes,
+						 uint16_t mode,
+						 list_t *preeemptee_candidates,
+						 list_t **preemptee_job_list,
+						 resv_exc_t *resv_exc_ptr,
+						 will_run_data_t *will_run_ptr);
+	int		(*job_begin)		(job_record_t *job_ptr);
+	int		(*job_ready)		(job_record_t *job_ptr);
+	int		(*job_expand)		(job_record_t *from_job_ptr,
+						 job_record_t *to_job_ptr);
+	int		(*job_resized)		(job_record_t *job_ptr,
+						 node_record_t *node_ptr);
+	int		(*job_fini)		(job_record_t *job_ptr);
+	int		(*job_suspend)		(job_record_t *job_ptr,
+						 bool indf_susp);
+	int		(*job_resume)		(job_record_t *job_ptr,
+						 bool indf_susp);
+	bitstr_t *      (*step_pick_nodes)      (job_record_t *job_ptr,
+						 select_jobinfo_t *step_jobinfo,
+						 uint32_t node_count,
+						 bitstr_t **avail_nodes);
+	int             (*step_start)           (step_record_t *step_ptr);
+	int             (*step_finish)          (step_record_t *step_ptr,
+						 bool killing_step);
+	int		(*nodeinfo_pack)	(select_nodeinfo_t *nodeinfo,
+						 buf_t *buffer,
+						 uint16_t protocol_version);
+	int		(*nodeinfo_unpack)	(select_nodeinfo_t **nodeinfo,
+						 buf_t *buffer,
+						 uint16_t protocol_version);
+	select_nodeinfo_t *(*nodeinfo_alloc)	(void);
+	int		(*nodeinfo_free)	(select_nodeinfo_t *nodeinfo);
+	int		(*nodeinfo_set_all)	(void);
+	int		(*nodeinfo_set)		(job_record_t *job_ptr);
+	int		(*nodeinfo_get)		(select_nodeinfo_t *nodeinfo,
+						 enum
+						 select_nodedata_type dinfo,
+						 enum node_states state,
+						 void *data);
+	select_jobinfo_t *(*jobinfo_alloc)	(void);
+	int		(*jobinfo_free)		(select_jobinfo_t *jobinfo);
+	int		(*jobinfo_set)		(select_jobinfo_t *jobinfo,
+						 enum
+						 select_jobdata_type data_type,
+						 void *data);
+	int		(*jobinfo_get)		(select_jobinfo_t *jobinfo,
+						 enum
+						 select_jobdata_type data_type,
+						 void *data);
+	select_jobinfo_t *(*jobinfo_copy)	(select_jobinfo_t *jobinfo);
+	int		(*jobinfo_pack)		(select_jobinfo_t *jobinfo,
+						 buf_t *buffer,
+						 uint16_t protocol_version);
+	int		(*jobinfo_unpack)	(select_jobinfo_t **jobinfo_pptr,
+						 buf_t *buffer,
+						 uint16_t protocol_version);
+	int		(*get_info_from_plugin)	(enum
+						 select_plugindata_info dinfo,
+						 job_record_t *job_ptr,
+						 void *data);
+	int		(*reconfigure)		(void);
+} slurm_select_ops_t;
+
+static const char *node_select_syms[] = {
 	"plugin_id",
 	"select_p_state_save",
 	"select_p_state_restore",
@@ -108,10 +175,7 @@ typedef struct {
 
 const plugin_id_name plugin_ids[] = {
 	{ SELECT_PLUGIN_LINEAR, "linear" },
-	{ SELECT_PLUGIN_SERIAL, "serial" },
-	{ SELECT_PLUGIN_CRAY_LINEAR, "cray_aries+linear" },
 	{ SELECT_PLUGIN_CONS_TRES, "cons_tres" },
-	{ SELECT_PLUGIN_CRAY_CONS_TRES, "cray_aries+cons_tres" },
 };
 
 extern char *select_plugin_id_to_string(int plugin_id)
@@ -174,7 +238,7 @@ extern int select_g_init(bool only_default)
 	int retval = SLURM_SUCCESS;
 	int i, j, plugin_cnt;
 	char *plugin_type = "select";
-	List plugin_names = NULL;
+	list_t *plugin_names = NULL;
 	_plugin_args_t plugin_args = {0};
 
 	slurm_mutex_lock( &select_context_lock );
@@ -182,18 +246,6 @@ extern int select_g_init(bool only_default)
 	if ( select_context )
 		goto done;
 
-	if (working_cluster_rec) {
-		/* just ignore warnings here */
-	} else {
-#ifdef HAVE_NATIVE_CRAY
-		if (xstrcasecmp(slurm_conf.select_type, "select/cray_aries")) {
-			error("%s is incompatible with a Cray/Aries system.",
-			      slurm_conf.select_type);
-			fatal("Use SelectType=select/cray_aries");
-		}
-#endif
-	}
-
 	select_context_cnt = 0;
 
 	plugin_args.plugin_type    = plugin_type;
@@ -280,76 +332,14 @@ fini:	slurm_mutex_unlock(&select_context_lock);
 /* Get this plugin's sequence number in Slurm's internal tables */
 extern int select_get_plugin_id_pos(uint32_t plugin_id)
 {
-	int i;
-	static bool cray_other_cons_tres = false;
-
 	xassert(select_context_cnt >= 0);
-again:
-	for (i = 0; i < select_context_cnt; i++) {
+
+	for (int i = 0; i < select_context_cnt; i++) {
 		if (*(ops[i].plugin_id) == plugin_id)
-			break;
+			return i;
 	}
-	if (i >= select_context_cnt) {
-		/*
-		 * Put on the extra Cray select plugins that do not get
-		 * generated automatically.
-		 */
-		if (!cray_other_cons_tres &&
-		    ((plugin_id == SELECT_PLUGIN_CRAY_CONS_TRES) ||
-		     (plugin_id == SELECT_PLUGIN_CRAY_LINEAR))) {
-			char *type = "select", *name = "select/cray_aries";
-			uint16_t save_params = slurm_conf.select_type_param;
-			uint16_t params;
-			int cray_plugin_id;
 
-			cray_other_cons_tres = true;
-
-			if (plugin_id == SELECT_PLUGIN_CRAY_LINEAR) {
-				params = save_params & ~CR_OTHER_CONS_TRES;
-				cray_plugin_id = SELECT_PLUGIN_CRAY_CONS_TRES;
-			} else {	/* SELECT_PLUGIN_CRAY_CONS_TRES */
-				params = save_params | CR_OTHER_CONS_TRES;
-				cray_plugin_id = SELECT_PLUGIN_CRAY_LINEAR;
-			}
-
-			for (i = 0; i < select_context_cnt; i++) {
-				if (*(ops[i].plugin_id) == cray_plugin_id)
-					break;
-			}
-
-			if (i >= select_context_cnt)
-				goto end_it;	/* No match */
-
-			slurm_mutex_lock(&select_context_lock);
-			slurm_conf.select_type_param = params;
-			plugin_context_destroy(select_context[i]);
-			select_context[i] =
-				plugin_context_create(type, name,
-						      (void **)&ops[i],
-						      node_select_syms,
-						      sizeof(node_select_syms));
-			slurm_conf.select_type_param = save_params;
-			slurm_mutex_unlock(&select_context_lock);
-			goto again;
-		}
-
-	end_it:
-		return SLURM_ERROR;
-	}
-	return i;
-}
-
-/* Get the plugin ID number. Unique for each select plugin type */
-extern int select_get_plugin_id(void)
-{
-	int plugin_pos;
-
-	xassert(select_context_cnt >= 0);
-
-	plugin_pos = working_cluster_rec ?
-		working_cluster_rec->plugin_id_select : select_context_default;
-
-	return *(ops[plugin_pos].plugin_id);
+	return SLURM_ERROR;
 }
 
 /* If the slurmctld is running a linear based select plugin return 1
@@ -362,7 +352,6 @@ extern int select_running_linear_based(void)
 
 	switch (*(ops[select_context_default].plugin_id)) {
 	case SELECT_PLUGIN_LINEAR: // select/linear
-	case SELECT_PLUGIN_CRAY_LINEAR: // select/cray -> linear
 		rc = 1;
 		break;
 	default:
@@ -399,11 +388,6 @@ extern char *select_type_param_string(uint16_t select_type_param)
 	else if (select_type_param & CR_MEMORY)
 		strcat(select_str, "CR_MEMORY");
 
-	if (select_type_param & CR_OTHER_CONS_TRES) {
-		if (select_str[0])
-			strcat(select_str, ",");
-		strcat(select_str, "OTHER_CONS_TRES");
-	}
 	if (select_type_param & CR_ONE_TASK_PER_CORE) {
 		if (select_str[0])
 			strcat(select_str, ",");
@@ -424,6 +408,26 @@ extern char *select_type_param_string(uint16_t select_type_param)
 			strcat(select_str, ",");
 		strcat(select_str, "CR_PACK_NODES");
 	}
+	if (select_type_param & LL_SHARED_GRES) {
+		if (select_str[0])
+			strcat(select_str, ",");
+		strcat(select_str, "LL_SHARED_GRES");
+	}
+	if (select_type_param & MULTIPLE_SHARING_GRES_PJ) {
+		if (select_str[0])
+			strcat(select_str, ",");
+		strcat(select_str, "MULTIPLE_SHARING_GRES_PJ");
+	}
+	if (select_type_param & ENFORCE_BINDING_GRES) {
+		if (select_str[0])
+			strcat(select_str, ",");
+		strcat(select_str, "ENFORCE_BINDING_GRES");
+	}
+	if (select_type_param & ONE_TASK_PER_SHARING_GRES) {
+		if (select_str[0])
+			strcat(select_str, ",");
+		strcat(select_str, "ONE_TASK_PER_SHARING_GRES");
+	}
 	if (select_str[0] == '\0')
 		strcat(select_str, "NONE");
 
@@ -466,7 +470,7 @@ extern int select_g_state_restore(char *dir_name)
  * Note the initialization of job records, issued upon restart of
  * slurmctld and used to synchronize any job state.
  */
-extern int select_g_job_init(List job_list)
+extern int select_g_job_init(list_t *job_list)
 {
 	xassert(select_context_cnt >= 0);
 
@@ -504,14 +508,16 @@ extern int select_g_node_init(void)
  *		if mode=SELECT_MODE_TEST_ONLY or input pointer is NULL.
  *		Existing list is appended to.
  * IN resv_exc_ptr - Various TRES which the job can NOT use.
- * RET zero on success, EINVAL otherwise
+ * IN will_run_ptr - Pointer to data specific to WILL_RUN mode
+ * RET SLURM_SUCCESS on success, rc otherwise
  */
 extern int select_g_job_test(job_record_t *job_ptr, bitstr_t *bitmap,
 			     uint32_t min_nodes, uint32_t max_nodes,
 			     uint32_t req_nodes, uint16_t mode,
-			     List preemptee_candidates,
-			     List *preemptee_job_list,
-			     resv_exc_t *resv_exc_ptr)
+			     list_t *preemptee_candidates,
+			     list_t **preemptee_job_list,
+			     resv_exc_t *resv_exc_ptr,
+			     will_run_data_t *will_run_ptr)
 {
 	xassert(select_context_cnt >= 0);
 
@@ -520,7 +526,8 @@ extern int select_g_job_test(job_record_t *job_ptr, bitstr_t *bitmap,
 		 min_nodes, max_nodes,
 		 req_nodes, mode,
 		 preemptee_candidates, preemptee_job_list,
-		 resv_exc_ptr);
+		 resv_exc_ptr,
+		 will_run_ptr);
 }
 
 /*
@@ -730,8 +737,6 @@ extern int select_g_select_nodeinfo_unpack(dynamic_plugin_data_t **nodeinfo,
 		/* cons_res was removed; convert to cons_tres */
 		if (plugin_id == SELECT_PLUGIN_CONS_RES) {
 			plugin_id = SELECT_PLUGIN_CONS_TRES;
-		} else if (plugin_id == SELECT_PLUGIN_CRAY_CONS_RES) {
-			plugin_id = SELECT_PLUGIN_CRAY_CONS_TRES;
 		}
 
 		if ((i = select_get_plugin_id_pos(plugin_id)) == SLURM_ERROR) {
@@ -775,17 +780,13 @@ unpack_error:
 extern dynamic_plugin_data_t *select_g_select_nodeinfo_alloc(void)
 {
 	dynamic_plugin_data_t *nodeinfo_ptr = NULL;
-	uint32_t plugin_id;
 
 	xassert(select_context_cnt >= 0);
-
-	plugin_id = working_cluster_rec ?
-		working_cluster_rec->plugin_id_select : select_context_default;
+	xassert(!working_cluster_rec);
 
 	nodeinfo_ptr = xmalloc(sizeof(dynamic_plugin_data_t));
-	nodeinfo_ptr->plugin_id = plugin_id;
-	nodeinfo_ptr->data = (*(ops[plugin_id].
-				nodeinfo_alloc))();
+	nodeinfo_ptr->plugin_id = select_context_default;
+	nodeinfo_ptr->data = (*(ops[select_context_default].nodeinfo_alloc))();
 	return nodeinfo_ptr;
 }
 
@@ -843,17 +844,13 @@ extern int select_g_select_nodeinfo_get(dynamic_plugin_data_t *nodeinfo,
 extern dynamic_plugin_data_t *select_g_select_jobinfo_alloc(void)
 {
 	dynamic_plugin_data_t *jobinfo_ptr = NULL;
-	uint32_t plugin_id;
 
 	xassert(select_context_cnt >= 0);
-
-	plugin_id = working_cluster_rec ?
-		working_cluster_rec->plugin_id_select : select_context_default;
+	xassert(!working_cluster_rec);
 
 	jobinfo_ptr = xmalloc(sizeof(dynamic_plugin_data_t));
-	jobinfo_ptr->plugin_id = plugin_id;
-	jobinfo_ptr->data =  (*(ops[plugin_id].
-				jobinfo_alloc))();
+	jobinfo_ptr->plugin_id = select_context_default;
+	jobinfo_ptr->data = (*(ops[select_context_default].jobinfo_alloc))();
 	return jobinfo_ptr;
 }
 
@@ -958,10 +955,7 @@ extern int select_g_select_jobinfo_pack(dynamic_plugin_data_t *jobinfo,
 	} else
 		plugin_id = select_context_default;
 
-	/*
-	 * Remove 2 versions after 23.02 -- 23.02 doesn't pack jobinfo anymore
-	 * AND the select plugin isn't loaded in the slurmd in 23.11.
-	 */
+	/* Remove when 23.02 is no longer supported. */
 	if (!running_in_slurmctld() &&
 	    (protocol_version <= SLURM_23_02_PROTOCOL_VERSION)) {
 		pack32(plugin_id, buffer);
@@ -992,10 +986,7 @@ extern int select_g_select_jobinfo_unpack(dynamic_plugin_data_t **jobinfo,
 {
 	dynamic_plugin_data_t *jobinfo_ptr = NULL;
 
-	/*
-	 * Remove 2 versions after 23.02 -- 23.02 doesn't pack jobinfo anymore
-	 * AND the select plugin isn't loaded in the slurmd in 23.11.
-	 */
+	/* Remove when 23.02 is no longer supported. */
 	if (!running_in_slurmctld() &&
 	    (protocol_version <= SLURM_23_02_PROTOCOL_VERSION)) {
 		uint32_t plugin_id;
@@ -1034,8 +1025,6 @@ extern int select_g_select_jobinfo_unpack(dynamic_plugin_data_t **jobinfo,
 		/* cons_res was removed; convert to cons_tres */
 		if (plugin_id == SELECT_PLUGIN_CONS_RES) {
 			plugin_id = SELECT_PLUGIN_CONS_TRES;
-		} else if (plugin_id == SELECT_PLUGIN_CRAY_CONS_RES) {
-			plugin_id = SELECT_PLUGIN_CRAY_CONS_TRES;
 		}
 
 		if ((i = select_get_plugin_id_pos(plugin_id)) == SLURM_ERROR) {
