@@ -44,6 +44,7 @@
 #include "as_mysql_wckey.h"
 
 #include "src/interfaces/select.h"
+#include "src/common/sluid.h"
 #include "src/common/slurm_time.h"
 
 /* if this changes you will need to edit the corresponding enum */
@@ -97,9 +98,9 @@ extern int as_mysql_get_fed_cluster_id(mysql_conn_t *mysql_conn,
 	xassert(ret_id);
 
 	/* See if cluster is already part of federation */
-	xstrfmtcat(query, "SELECT name, fed_id "
-			  "FROM %s "
-			  "WHERE deleted=0 AND name='%s' AND federation='%s';",
+	xstrfmtcat(query,
+		   "SELECT name, fed_id FROM %s "
+		   "WHERE deleted=0 AND name='%s' AND federation='%s';",
 		   cluster_table, cluster, federation);
 	DB_DEBUG(FEDR, mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
@@ -119,11 +120,11 @@ extern int as_mysql_get_fed_cluster_id(mysql_conn_t *mysql_conn,
 	mysql_free_result(result);
 
 	/* Get all other clusters in the federation and find an open id. */
-	xstrfmtcat(query, "SELECT name, federation, fed_id "
-		   	  "FROM %s "
-		   	  "WHERE name!='%s' AND federation='%s' "
-			  "AND fed_id > %d AND deleted=0 ORDER BY fed_id;",
-			  cluster_table, cluster, federation, last_id);
+	xstrfmtcat(query,
+		   "SELECT name, federation, fed_id FROM %s "
+		   "WHERE name!='%s' AND federation='%s' "
+		   "AND fed_id > %d AND deleted=0 ORDER BY fed_id;",
+		   cluster_table, cluster, federation, last_id);
 	DB_DEBUG(FEDR, mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
@@ -155,7 +156,7 @@ static int _setup_cluster_cond_limits(slurmdb_cluster_cond_t *cluster_cond,
 				      char **extra)
 {
 	int set = 0;
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	char *object = NULL;
 
 	if (!cluster_cond)
@@ -224,10 +225,53 @@ static int _setup_cluster_cond_limits(slurmdb_cluster_cond_t *cluster_cond,
 	return set;
 }
 
-extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
-				 List cluster_list)
+extern uint16_t as_mysql_cluster_get_unique_id(
+	mysql_conn_t *mysql_conn, char *cluster_name)
 {
-	ListIterator itr = NULL;
+	MYSQL_RES *result = NULL;
+	MYSQL_ROW row;
+	uint16_t id = 0;
+	char *query = NULL;
+	int num_rows;
+
+	/* First check to see if we are already here with an id. */
+	query = xstrdup_printf("select id from %s where name='%s';",
+			       cluster_table, cluster_name);
+	result = mysql_db_query_ret(mysql_conn, query, 0);
+	xfree(query);
+
+	if (!result)
+		fatal("No cluster table?");
+
+	if ((row = mysql_fetch_row(result)) && row[0])
+		id = slurm_atoul(row[0]);
+
+	mysql_free_result(result);
+
+	while (!id) {
+		id = generate_cluster_id();
+
+		/* Test to make sure we aren't a duplicate */
+		query = xstrdup_printf("select id from %s where id=%u;",
+				       cluster_table, id);
+		result = mysql_db_query_ret(mysql_conn, query, 0);
+		xfree(query);
+		num_rows = mysql_num_rows(result);
+		mysql_free_result(result);
+
+		/* Unique */
+		if (!num_rows)
+			break;
+		id = 0;
+	}
+
+	return id;
+}
+
+extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
+				 list_t *cluster_list)
+{
+	list_itr_t *itr = NULL;
 	int rc = SLURM_SUCCESS;
 	slurmdb_cluster_rec_t *object = NULL;
 	char *extra = NULL,
@@ -237,7 +281,7 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 	int affect_rows = 0;
 	int added = 0;
 	bool has_feds = false;
-	List assoc_list = NULL;
+	list_t *assoc_list = NULL;
 	slurmdb_assoc_rec_t *assoc = NULL;
 	bool external_cluster = false;
 
@@ -290,6 +334,7 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		int fed_id = 0;
 		uint16_t fed_state = CLUSTER_FED_STATE_NA;
 		char *features = NULL;
+		uint16_t id;
 
 		if (object->fed.name) {
 			has_feds = 1;
@@ -313,26 +358,27 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		if (object->fed.feature_list) {
 			features =
 				slurm_char_list_to_xstr(
-						object->fed.feature_list);
+					object->fed.feature_list);
 			has_feds = 1;
 		}
 
+		id = as_mysql_cluster_get_unique_id(mysql_conn, object->name);
+
 		xstrfmtcat(query,
 			   "insert into %s (creation_time, mod_time, "
-			   "name, classification, federation, fed_id, "
+			   "name, id, classification, federation, fed_id, "
 			   "fed_state, features) "
-			   "values (%ld, %ld, '%s', %u, '%s', %d, %u, '%s') "
+			   "values (%ld, %ld, '%s', %d, %u, '%s', %d, %u, '%s') "
 			   "on duplicate key update deleted=0, mod_time=%ld, "
-			   "control_host='', control_port=0, "
 			   "classification=%u, flags=0, federation='%s', "
-			   "fed_id=%d, fed_state=%u, features='%s'",
+			   "fed_id=%d, fed_state=%u, features='%s', id=%u",
 			   cluster_table,
-			   now, now, object->name, object->classification,
+			   now, now, object->name, id, object->classification,
 			   (object->fed.name) ? object->fed.name : "",
 			   fed_id, fed_state, (features) ? features : "",
 			   now, object->classification,
 			   (object->fed.name) ? object->fed.name : "",
-			   fed_id, fed_state, (features) ? features : "");
+			   fed_id, fed_state, (features) ? features : "", id);
 		DB_DEBUG(DB_ASSOC, mysql_conn->conn, "query\n%s", query);
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
@@ -406,7 +452,8 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 			 * to set things up. Since it isn't there yet it
 			 * won't work.
 			 */
-
+			if (object->root_assoc->def_qos_id == INFINITE)
+				object->root_assoc->def_qos_id = 0;
 			xfree(object->root_assoc->cluster);
 			object->root_assoc->cluster = xstrdup(object->name);
 			xfree(object->root_assoc->acct);
@@ -431,8 +478,9 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		}
 
 		/* Build up extra with cluster specfic values for txn table */
-		xstrfmtcat(extra, ", federation='%s', fed_id=%d, fed_state=%u, "
-				  "features='%s'",
+		xstrfmtcat(extra,
+			   ", federation='%s', fed_id=%d, fed_state=%u, "
+			   "features='%s'",
 			   (object->fed.name) ? object->fed.name : "",
 			   fed_id, fed_state, (features) ? features : "");
 		xfree(features);
@@ -456,7 +504,7 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		if (rc != SLURM_SUCCESS) {
 			error("Couldn't add txn");
 		} else {
-			ListIterator check_itr;
+			list_itr_t *check_itr;
 			char *tmp_name;
 
 			added++;
@@ -523,7 +571,7 @@ end_it:
 static int _reconcile_existing_features(void *object, void *arg)
 {
 	char *new_feature = (char *)object;
-	List existing_features = (List)arg;
+	list_t *existing_features = arg;
 
 	if (new_feature[0] == '-')
 		list_delete_all(existing_features, slurm_find_char_in_list,
@@ -536,11 +584,11 @@ static int _reconcile_existing_features(void *object, void *arg)
 	return SLURM_SUCCESS;
 }
 
-extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
-				     slurmdb_cluster_cond_t *cluster_cond,
-				     slurmdb_cluster_rec_t *cluster)
+extern list_t *as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
+					slurmdb_cluster_cond_t *cluster_cond,
+					slurmdb_cluster_rec_t *cluster)
 {
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 	int rc = SLURM_SUCCESS;
 	char *object = NULL;
 	char *vals = NULL, *extra = NULL, *query = NULL, *name_char = NULL;
@@ -602,11 +650,6 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		clust_reg = true;
 	}
 
-	if (cluster->plugin_id_select) {
-		xstrfmtcat(vals, ", plugin_id_select=%u",
-			   cluster->plugin_id_select);
-		clust_reg = true;
-	}
 	if (cluster->flags != NO_VAL) {
 		xstrfmtcat(vals, ", flags=%u", cluster->flags);
 		clust_reg = true;
@@ -641,7 +684,7 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		return NULL;
 	}
 
-	xstrfmtcat(query, "select name, control_port, federation, features from %s%s;",
+	xstrfmtcat(query, "select name, control_port, federation, features, id from %s%s;",
 		   cluster_table, extra);
 
 	DB_DEBUG(DB_ASSOC, mysql_conn->conn, "query\n%s", query);
@@ -661,6 +704,8 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		char *tmp_vals = xstrdup(vals);
 
 		object = xstrdup(row[0]);
+		if (clust_reg)
+			cluster->id = slurm_atoul(row[4]);
 
 		if (cluster->fed.name) {
 			int id = 0;
@@ -669,9 +714,9 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 			if (cluster->fed.name[0] != '\0') {
 				rc = as_mysql_get_fed_cluster_id(
-							mysql_conn, object,
-							cluster->fed.name, -1,
-							&id);
+					mysql_conn, object,
+					cluster->fed.name, -1,
+					&id);
 				if (rc) {
 					error("failed to get cluster id for "
 					      "federation");
@@ -709,7 +754,7 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 				xstrfmtcat(tmp_vals, ", features=''");
 			} else {
 				char *features = NULL, *feature = NULL;
-				List existing_features = list_create(xfree_ptr);
+				list_t *existing_features = list_create(xfree_ptr);
 
 				if ((feature =
 				     list_peek(cluster->fed.feature_list)) &&
@@ -723,7 +768,7 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 				features =
 					slurm_char_list_to_xstr(
-							existing_features);
+						existing_features);
 				xstrfmtcat(tmp_vals, ", features='%s'",
 					   features ? features : "");
 
@@ -773,12 +818,12 @@ end_it:
 	return ret_list;
 }
 
-extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
-				     slurmdb_cluster_cond_t *cluster_cond)
+extern list_t *as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
+					slurmdb_cluster_cond_t *cluster_cond)
 {
-	ListIterator itr = NULL;
-	List ret_list = NULL;
-	List tmp_list = NULL;
+	list_itr_t *itr = NULL;
+	list_t *ret_list = NULL;
+	list_t *tmp_list = NULL;
 	int rc = SLURM_SUCCESS;
 	char *object = NULL;
 	char *extra = NULL, *query = NULL, *cluster_name = NULL,
@@ -853,17 +898,7 @@ extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 		xfree(name_char);
 		xstrfmtcat(name_char, "name='%s'", object);
-		/* We should not need to delete any cluster usage just set it
-		 * to deleted */
-		xstrfmtcat(query,
-			   "update \"%s_%s\" set time_end=%ld where time_end=0;"
-			   "update \"%s_%s\" set mod_time=%ld, deleted=1;"
-			   "update \"%s_%s\" set mod_time=%ld, deleted=1;"
-			   "update \"%s_%s\" set mod_time=%ld, deleted=1;",
-			   object, event_table, now,
-			   object, cluster_day_table, now,
-			   object, cluster_hour_table, now,
-			   object, cluster_month_table, now);
+
 		rc = remove_common(mysql_conn, DBD_REMOVE_CLUSTERS, now,
 				   user_name, cluster_table, name_char,
 				   assoc_char, object, ret_list, &jobs_running,
@@ -879,19 +914,9 @@ extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 	if (rc != SLURM_SUCCESS) {
 		FREE_NULL_LIST(ret_list);
-		xfree(query);
 		return NULL;
 	}
 	if (!jobs_running) {
-		DB_DEBUG(DB_ASSOC, mysql_conn->conn, "query\n%s", query);
-		rc = mysql_db_query(mysql_conn, query);
-		xfree(query);
-		if (rc != SLURM_SUCCESS) {
-			reset_mysql_conn(mysql_conn);
-			FREE_NULL_LIST(ret_list);
-			return NULL;
-		}
-
 		/* We need to remove these clusters from the wckey table */
 		memset(&wckey_cond, 0, sizeof(slurmdb_wckey_cond_t));
 		wckey_cond.cluster_list = ret_list;
@@ -930,26 +955,27 @@ extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 	return ret_list;
 }
 
-extern List as_mysql_get_clusters(mysql_conn_t *mysql_conn, uid_t uid,
-				  slurmdb_cluster_cond_t *cluster_cond)
+extern list_t *as_mysql_get_clusters(mysql_conn_t *mysql_conn, uid_t uid,
+				     slurmdb_cluster_cond_t *cluster_cond)
 {
 	char *query = NULL;
 	char *extra = NULL;
 	char *tmp = NULL;
-	List cluster_list = NULL;
-	ListIterator itr = NULL;
+	list_t *cluster_list = NULL;
+	list_itr_t *itr = NULL;
 	int i=0;
 	MYSQL_RES *result = NULL;
 	MYSQL_ROW row;
 	slurmdb_assoc_cond_t assoc_cond;
-	ListIterator assoc_itr = NULL;
+	list_itr_t *assoc_itr = NULL;
 	slurmdb_cluster_rec_t *cluster = NULL;
 	slurmdb_assoc_rec_t *assoc = NULL;
-	List assoc_list = NULL;
+	list_t *assoc_list = NULL;
 
 	/* if this changes you will need to edit the corresponding enum */
 	char *cluster_req_inx[] = {
 		"name",
+		"id",
 		"classification",
 		"control_host",
 		"control_port",
@@ -960,10 +986,10 @@ extern List as_mysql_get_clusters(mysql_conn_t *mysql_conn, uid_t uid,
 		"rpc_version",
 		"dimensions",
 		"flags",
-		"plugin_id_select"
 	};
 	enum {
 		CLUSTER_REQ_NAME,
+		CLUSTER_REQ_ID,
 		CLUSTER_REQ_CLASS,
 		CLUSTER_REQ_CH,
 		CLUSTER_REQ_CP,
@@ -974,7 +1000,6 @@ extern List as_mysql_get_clusters(mysql_conn_t *mysql_conn, uid_t uid,
 		CLUSTER_REQ_VERSION,
 		CLUSTER_REQ_DIMS,
 		CLUSTER_REQ_FLAGS,
-		CLUSTER_REQ_PI_SELECT,
 		CLUSTER_REQ_COUNT
 	};
 
@@ -1019,7 +1044,8 @@ empty:
 		/* I don't think we want the with_usage flag here.
 		 * We do need the with_deleted though. */
 		//assoc_cond.with_usage = cluster_cond->with_usage;
-		assoc_cond.with_deleted = cluster_cond->with_deleted;
+		if (cluster_cond->with_deleted)
+			assoc_cond.flags |= ASSOC_COND_FLAG_WITH_DELETED;
 	}
 	assoc_cond.cluster_list = list_create(NULL);
 
@@ -1032,6 +1058,7 @@ empty:
 		list_append(cluster_list, cluster);
 
 		cluster->name = xstrdup(row[CLUSTER_REQ_NAME]);
+		cluster->id = slurm_atoul(row[CLUSTER_REQ_ID]);
 
 		list_append(assoc_cond.cluster_list, cluster->name);
 
@@ -1050,8 +1077,6 @@ empty:
 		cluster->rpc_version = slurm_atoul(row[CLUSTER_REQ_VERSION]);
 		cluster->dimensions = slurm_atoul(row[CLUSTER_REQ_DIMS]);
 		cluster->flags = slurm_atoul(row[CLUSTER_REQ_FLAGS]);
-		cluster->plugin_id_select =
-			slurm_atoul(row[CLUSTER_REQ_PI_SELECT]);
 
 		query = xstrdup_printf(
 			"select tres, cluster_nodes from "
@@ -1128,21 +1153,21 @@ empty:
 	return cluster_list;
 }
 
-extern List as_mysql_get_cluster_events(mysql_conn_t *mysql_conn, uint32_t uid,
-					slurmdb_event_cond_t *event_cond)
+extern list_t *as_mysql_get_cluster_events(mysql_conn_t *mysql_conn, uint32_t uid,
+					   slurmdb_event_cond_t *event_cond)
 {
 	char *query = NULL;
 	char *extra = NULL;
 	char *tmp = NULL;
-	List ret_list = NULL;
-	ListIterator itr = NULL;
+	list_t *ret_list = NULL;
+	list_itr_t *itr = NULL;
 	char *object = NULL;
 	int set = 0;
 	int i=0;
 	MYSQL_RES *result = NULL;
 	MYSQL_ROW row;
 	time_t now = time(NULL);
-	List use_cluster_list = NULL;
+	list_t *use_cluster_list = NULL;
 	slurmdb_user_rec_t user;
 	bool locked = false;
 
@@ -1154,7 +1179,7 @@ extern List as_mysql_get_cluster_events(mysql_conn_t *mysql_conn, uint32_t uid,
 
 	if (slurm_conf.private_data & PRIVATE_DATA_EVENTS) {
 		if (!is_user_min_admin_level(
-			      mysql_conn, uid, SLURMDB_ADMIN_OPERATOR)) {
+			    mysql_conn, uid, SLURMDB_ADMIN_OPERATOR)) {
 			error("UID %u tried to access events, only administrators can look at events",
 			      uid);
 			errno = ESLURM_ACCESS_DENIED;
@@ -1501,11 +1526,11 @@ static slurmdb_instance_rec_t *_create_instance_rec(MYSQL_ROW row,
 	return instance;
 }
 
-static void _add_char_list_to_where_clause(List char_list,
+static void _add_char_list_to_where_clause(list_t *char_list,
 					   const char *col_name,
 					   char **where_clause)
 {
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	int set = 0;
 	char *string = NULL;
 
@@ -1529,9 +1554,8 @@ static void _add_char_list_to_where_clause(List char_list,
 	}
 }
 
-extern List as_mysql_get_instances(mysql_conn_t *mysql_conn,
-				   uint32_t uid,
-				   slurmdb_instance_cond_t *instance_cond)
+extern list_t *as_mysql_get_instances(mysql_conn_t *mysql_conn, uint32_t uid,
+				      slurmdb_instance_cond_t *instance_cond)
 {
 	bool locked = false;
 	char *cluster = NULL;
@@ -1541,9 +1565,9 @@ extern List as_mysql_get_instances(mysql_conn_t *mysql_conn,
 	char *tmp = NULL;
 	int i = 0;
 	int set = 0;
-	List ret_list = NULL;
-	List use_cluster_list = NULL;
-	ListIterator itr = NULL;
+	list_t *ret_list = NULL;
+	list_t *use_cluster_list = NULL;
+	list_itr_t *itr = NULL;
 	MYSQL_RES *result = NULL;
 	MYSQL_ROW row, prev_row = NULL;
 	slurmdb_user_rec_t user;
