@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  as_mysql_federation.c - functions dealing with federations.
  *****************************************************************************
- *  Copyright (C) 2016 SchedMD LLC.
- *  Written by Brian Christiansen <brian@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -51,7 +50,7 @@ static int _setup_federation_cond_limits(slurmdb_federation_cond_t *fed_cond,
 					 char **extra)
 {
 	int set = 0;
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	char *object = NULL;
 
 	if (!fed_cond)
@@ -129,7 +128,7 @@ static int _setup_federation_rec_limits(slurmdb_federation_rec_t *fed,
  * IN: exceptions - list of clusters to not remove.
  */
 static int _remove_all_clusters_from_fed(mysql_conn_t *mysql_conn,
-					 const char *fed, List exceptions)
+					 const char *fed, list_t *exceptions)
 {
 	int   rc    = SLURM_SUCCESS;
 	char *query = NULL;
@@ -137,7 +136,7 @@ static int _remove_all_clusters_from_fed(mysql_conn_t *mysql_conn,
 
 	if (exceptions && list_count(exceptions)) {
 		char *tmp_name;
-		ListIterator itr;
+		list_itr_t *itr;
 
 		itr = list_iterator_create(exceptions);
 		while ((tmp_name = list_next(itr)))
@@ -147,9 +146,9 @@ static int _remove_all_clusters_from_fed(mysql_conn_t *mysql_conn,
 		list_iterator_destroy(itr);
 	}
 
-	xstrfmtcat(query, "UPDATE %s "
-		   	  "SET federation='', fed_id=0, fed_state=%u "
-			  "WHERE federation='%s' and deleted=0",
+	xstrfmtcat(query,
+		   "UPDATE %s SET federation='', fed_id=0, fed_state=%u "
+		   "WHERE federation='%s' and deleted=0",
 		   cluster_table, CLUSTER_FED_STATE_NA, fed);
 	if (exception_names)
 		xstrfmtcat(query, " AND name NOT IN (%s)", exception_names);
@@ -167,23 +166,23 @@ static int _remove_all_clusters_from_fed(mysql_conn_t *mysql_conn,
 	return rc;
 }
 
-static int _remove_clusters_from_fed(mysql_conn_t *mysql_conn, List clusters)
+static int _remove_clusters_from_fed(mysql_conn_t *mysql_conn, list_t *clusters)
 {
 	int   rc    = SLURM_SUCCESS;
 	char *query = NULL;
 	char *name  = NULL;
 	char *names = NULL;
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 
 	xassert(clusters);
 
 	itr = list_iterator_create(clusters);
 	while ((name = list_next(itr)))
-	       xstrfmtcat(names, "%s'%s'", names ? "," : "", name );
+		xstrfmtcat(names, "%s'%s'", names ? "," : "", name );
 
-	xstrfmtcat(query, "UPDATE %s "
-		   	  "SET federation='', fed_id=0, fed_state=%u "
-			  "WHERE name IN (%s) and deleted=0",
+	xstrfmtcat(query,
+		   "UPDATE %s SET federation='', fed_id=0, fed_state=%u "
+		   "WHERE name IN (%s) and deleted=0",
 		   cluster_table, CLUSTER_FED_STATE_NA, names);
 
 	DB_DEBUG(FEDR, mysql_conn->conn, "query\n%s", query);
@@ -197,7 +196,7 @@ static int _remove_clusters_from_fed(mysql_conn_t *mysql_conn, List clusters)
 	return rc;
 }
 
-static int _add_clusters_to_fed(mysql_conn_t *mysql_conn, List clusters,
+static int _add_clusters_to_fed(mysql_conn_t *mysql_conn, list_t *clusters,
 				const char *fed)
 {
 	int   rc      = SLURM_SUCCESS;
@@ -205,7 +204,7 @@ static int _add_clusters_to_fed(mysql_conn_t *mysql_conn, List clusters,
 	char *name    = NULL;
 	char *names   = NULL;
 	char *indexes = NULL;
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	int   last_id = -1;
 
 	xassert(fed);
@@ -228,12 +227,12 @@ static int _add_clusters_to_fed(mysql_conn_t *mysql_conn, List clusters,
 	 * in the fed_state case statement must happen before fed_state is set
 	 * or the federation will always equal the federation in the case
 	 * statement.  */
-	xstrfmtcat(query, "UPDATE %s "
-		   	  "SET "
-			  "fed_state = CASE WHEN federation='%s' THEN fed_state ELSE %u END, "
-			  "fed_id = CASE %s END, "
-		   	  "federation='%s' "
-			  "WHERE name IN (%s) and deleted=0",
+	xstrfmtcat(query,
+		   "UPDATE %s SET "
+		   "fed_state = CASE WHEN federation='%s' THEN fed_state ELSE %u END, "
+		   "fed_id = CASE %s END, "
+		   "federation='%s' "
+		   "WHERE name IN (%s) and deleted=0",
 		   cluster_table, fed, CLUSTER_FED_STATE_ACTIVE, indexes, fed,
 		   names);
 
@@ -255,12 +254,12 @@ end_it:
 
 static int _assign_clusters_to_federation(mysql_conn_t *mysql_conn,
 					  const char *federation,
-					  List cluster_list)
+					  list_t *cluster_list)
 {
 	int  rc       = SLURM_SUCCESS;
-	List add_list = NULL;
-	List rem_list = NULL;
-	ListIterator itr    = NULL;
+	list_t *add_list = NULL;
+	list_t *rem_list = NULL;
+	list_itr_t *itr = NULL;
 	bool clear_clusters = false;
 	slurmdb_cluster_rec_t *tmp_cluster = NULL;
 
@@ -310,13 +309,13 @@ end_it:
 }
 
 extern int as_mysql_add_federations(mysql_conn_t *mysql_conn, uint32_t uid,
-				    List federation_list)
+				    list_t *federation_list)
 {
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	int rc = SLURM_SUCCESS;
 	slurmdb_federation_rec_t *object = NULL;
 	char *cols = NULL, *vals = NULL, *extra = NULL, *query = NULL,
-	     *tmp_extra = NULL;
+		*tmp_extra = NULL;
 	time_t now = time(NULL);
 	char *user_name = NULL;
 	int affect_rows = 0;
@@ -423,13 +422,14 @@ extern int as_mysql_add_federations(mysql_conn_t *mysql_conn, uint32_t uid,
 	return rc;
 }
 
-extern List as_mysql_get_federations(mysql_conn_t *mysql_conn, uid_t uid,
-				     slurmdb_federation_cond_t *federation_cond)
+extern list_t *as_mysql_get_federations(
+	mysql_conn_t *mysql_conn, uid_t uid,
+	slurmdb_federation_cond_t *federation_cond)
 {
 	char *query = NULL;
 	char *extra = NULL;
 	char *tmp = NULL;
-	List federation_list = NULL;
+	list_t *federation_list = NULL;
 	int i=0;
 	MYSQL_RES *result = NULL;
 	MYSQL_ROW row;
@@ -474,7 +474,7 @@ empty:
 
 	while ((row = mysql_fetch_row(result))) {
  		slurmdb_cluster_cond_t clus_cond;
- 		List tmp_list = NULL;
+		list_t *tmp_list = NULL;
  		fed = xmalloc(sizeof(slurmdb_federation_rec_t));
  		list_append(federation_list, fed);
 
@@ -499,17 +499,17 @@ empty:
 	return federation_list;
 }
 
-extern List as_mysql_modify_federations(
-				mysql_conn_t *mysql_conn, uint32_t uid,
-				slurmdb_federation_cond_t *fed_cond,
-				slurmdb_federation_rec_t *fed)
+extern list_t *as_mysql_modify_federations(
+	mysql_conn_t *mysql_conn, uint32_t uid,
+	slurmdb_federation_cond_t *fed_cond,
+	slurmdb_federation_rec_t *fed)
 {
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 	int rc = SLURM_SUCCESS;
 	int req_inx = 0;
 	char *object = NULL;
 	char *vals = NULL, *extra = NULL, *query = NULL,
-	     *name_char = NULL, *fed_items = NULL;
+		*name_char = NULL, *fed_items = NULL;
 	char *tmp_char1 = NULL, *tmp_char2 = NULL;
 	time_t now = time(NULL);
 	MYSQL_RES *result = NULL;
@@ -632,10 +632,11 @@ extern List as_mysql_modify_federations(
 	return ret_list;
 }
 
-extern List as_mysql_remove_federations(mysql_conn_t *mysql_conn, uint32_t uid,
-					slurmdb_federation_cond_t *fed_cond)
+extern list_t *as_mysql_remove_federations(mysql_conn_t *mysql_conn,
+					   uint32_t uid,
+					   slurmdb_federation_cond_t *fed_cond)
 {
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 	int rc = SLURM_SUCCESS;
 	char *extra = NULL, *query = NULL, *name_char = NULL;
 	time_t now = time(NULL);
