@@ -189,10 +189,10 @@ static int _make_sure_user_has_default_internal(
  * adding a new wckey for a user that has never been on the cluster before.
  */
 static int _make_sure_users_have_default(
-	mysql_conn_t *mysql_conn, List user_list, List cluster_list)
+	mysql_conn_t *mysql_conn, list_t *user_list, list_t *cluster_list)
 {
 	char *cluster = NULL, *user = NULL;
-	ListIterator itr = NULL, clus_itr = NULL;
+	list_itr_t *itr = NULL, *clus_itr = NULL;
 	int rc = SLURM_SUCCESS;
 
 	if (!user_list)
@@ -224,7 +224,7 @@ static int _setup_wckey_cond_limits(slurmdb_wckey_cond_t *wckey_cond,
 				    char **extra)
 {
 	int set = 0;
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	char *object = NULL;
 	char *prefix = "t1";
 	if (!wckey_cond)
@@ -291,7 +291,7 @@ static int _cluster_remove_wckeys(mysql_conn_t *mysql_conn,
 				  char *extra,
 				  char *cluster_name,
 				  char *user_name,
-				  List ret_list)
+				  list_t *ret_list)
 {
 	int rc = SLURM_SUCCESS;
 	MYSQL_RES *result = NULL;
@@ -362,7 +362,7 @@ static int _cluster_modify_wckeys(mysql_conn_t *mysql_conn,
 				  slurmdb_wckey_rec_t *wckey,
 				  char *cluster_name, char *extra,
 				  char *vals, char *user_name,
-				  List ret_list)
+				  list_t *ret_list)
 {
 	int rc = SLURM_SUCCESS;
 	MYSQL_RES *result = NULL;
@@ -380,8 +380,11 @@ static int _cluster_modify_wckeys(mysql_conn_t *mysql_conn,
 	}
 
 	/* This key doesn't exist on this cluster, that is ok. */
-	if (!mysql_num_rows(result))
+	if (!mysql_num_rows(result)) {
+		xfree(query);
+		mysql_free_result(result);
 		return SLURM_SUCCESS;
+	}
 
 	while ((row = mysql_fetch_row(result))) {
 		slurmdb_wckey_rec_t *wckey_rec = NULL;
@@ -445,9 +448,9 @@ static int _cluster_get_wckeys(mysql_conn_t *mysql_conn,
 			       char *fields,
 			       char *extra,
 			       char *cluster_name,
-			       List sent_list)
+			       list_t *sent_list)
 {
-	List wckey_list = NULL;
+	list_t *wckey_list = NULL;
 	MYSQL_RES *result = NULL;
 	MYSQL_ROW row;
 	char *query = NULL;
@@ -665,9 +668,9 @@ static int _add_wckey_cond_cluster(void *x, void *arg)
 /* extern functions */
 
 extern int as_mysql_add_wckeys(mysql_conn_t *mysql_conn, uint32_t uid,
-			       List wckey_list)
+			       list_t *wckey_list)
 {
-	ListIterator itr = NULL;
+	list_itr_t *itr = NULL;
 	int rc = SLURM_SUCCESS;
 	slurmdb_wckey_rec_t *object = NULL;
 	char *cols = NULL, *extra = NULL, *vals = NULL, *query = NULL,
@@ -676,8 +679,8 @@ extern int as_mysql_add_wckeys(mysql_conn_t *mysql_conn, uint32_t uid,
 	char *user_name = NULL;
 	int affect_rows = 0;
 	int added = 0;
-	List local_cluster_list = NULL;
-	List added_user_list = NULL;
+	list_t *local_cluster_list = NULL;
+	list_t *added_user_list = NULL;
 
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
@@ -864,7 +867,14 @@ extern char *as_mysql_add_wckeys_cond(mysql_conn_t *mysql_conn, uint32_t uid,
 		use_cluster_list = as_mysql_cluster_list;
 
 	memset(&add_wckey_cond, 0, sizeof(add_wckey_cond));
-	add_wckey_cond.default_wckey = user->default_wckey;
+	if (user->default_wckey) {
+		add_wckey_cond.default_wckey = user->default_wckey;
+	} else {
+		add_wckey_cond.default_wckey = list_peek(add_assoc->wckey_list);
+		DB_DEBUG(DB_WCKEY, mysql_conn->conn,
+			 "Default wckey not given, using %s",
+			 add_wckey_cond.default_wckey);
+	}
 	add_wckey_cond.mysql_conn = mysql_conn;
 	add_wckey_cond.now = time(NULL);
 	add_wckey_cond.user_list = add_assoc->user_list;
@@ -903,17 +913,17 @@ extern char *as_mysql_add_wckeys_cond(mysql_conn_t *mysql_conn, uint32_t uid,
 	return add_wckey_cond.ret_str;
 }
 
-extern List as_mysql_modify_wckeys(mysql_conn_t *mysql_conn,
-				   uint32_t uid,
-				   slurmdb_wckey_cond_t *wckey_cond,
-				   slurmdb_wckey_rec_t *wckey)
+extern list_t *as_mysql_modify_wckeys(mysql_conn_t *mysql_conn,
+				      uint32_t uid,
+				      slurmdb_wckey_cond_t *wckey_cond,
+				      slurmdb_wckey_rec_t *wckey)
 {
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 	int rc = SLURM_SUCCESS;
 	char *extra = NULL, *object = NULL, *vals = NULL;
 	char *user_name = NULL;
-	List use_cluster_list = NULL;
-	ListIterator itr;
+	list_t *use_cluster_list = NULL;
+	list_itr_t *itr;
 	bool locked = false;
 
 	if (!wckey_cond || !wckey) {
@@ -979,6 +989,7 @@ is_same_user:
 	}
 	list_iterator_destroy(itr);
 	xfree(extra);
+	xfree(vals);
 	xfree(user_name);
 
 	if (locked) {
@@ -994,16 +1005,16 @@ is_same_user:
 	return ret_list;
 }
 
-extern List as_mysql_remove_wckeys(mysql_conn_t *mysql_conn,
-				   uint32_t uid,
-				   slurmdb_wckey_cond_t *wckey_cond)
+extern list_t *as_mysql_remove_wckeys(mysql_conn_t *mysql_conn,
+				      uint32_t uid,
+				      slurmdb_wckey_cond_t *wckey_cond)
 {
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 	int rc = SLURM_SUCCESS;
 	char *extra = NULL, *object = NULL;
 	char *user_name = NULL;
-	List use_cluster_list = NULL;
-	ListIterator itr;
+	list_t *use_cluster_list = NULL;
+	list_itr_t *itr;
 	bool locked = false;
 
 	if (!wckey_cond) {
@@ -1062,18 +1073,18 @@ empty:
 	return ret_list;
 }
 
-extern List as_mysql_get_wckeys(mysql_conn_t *mysql_conn, uid_t uid,
-				slurmdb_wckey_cond_t *wckey_cond)
+extern list_t *as_mysql_get_wckeys(mysql_conn_t *mysql_conn, uid_t uid,
+				   slurmdb_wckey_cond_t *wckey_cond)
 {
 	//DEF_TIMERS;
 	char *extra = NULL;
 	char *tmp = NULL;
 	char *cluster_name = NULL;
-	List wckey_list = NULL;
+	list_t *wckey_list = NULL;
 	int i=0, is_admin=1;
 	slurmdb_user_rec_t user;
-	List use_cluster_list = NULL;
-	ListIterator itr;
+	list_t *use_cluster_list = NULL;
+	list_itr_t *itr;
 	bool locked = false;
 
 	if (!wckey_cond) {
