@@ -153,7 +153,7 @@ static int  _check_params(void);
 static void _free_options(void);
 static void _remove_empty_output(void);
 static int _list_items(void);
-static int _fields_intersection(hid_t fid_job, List tables, List fields);
+static int _fields_intersection(hid_t fid_job, list_t *tables, list_t *fields);
 
 static void _help_msg(void)
 {
@@ -593,7 +593,7 @@ static int _merge_step_files(void)
 	int job_id;
 	int rc = SLURM_SUCCESS;
 	list_itr_t *itr;
-	List file_list = NULL;
+	list_t *file_list = NULL;
 	sh5util_file_t *sh5util_file = NULL;
 
 	step_dir = xstrdup_printf("%s/%s", params.dir, params.user);
@@ -783,7 +783,7 @@ static void _table_path(table_t *t, char *path)
 static herr_t _collect_tables_group(hid_t g_id, const char *name,
                                     const H5L_info_t *link_info, void *op_data)
 {
-	List tables = (List)op_data;
+	list_t *tables = op_data;
 	hid_t table_id = -1;
 
 	/* open the dataset. */
@@ -809,7 +809,7 @@ static herr_t _collect_tables_node(hid_t g_id, const char *name,
                                    const H5L_info_t *link_info, void *op_data)
 {
 	char object_path[PATH_MAX];
-	List tables = (List)op_data;
+	list_t *tables = op_data;
 	hid_t object_id = -1;
 	herr_t err;
 
@@ -879,7 +879,7 @@ static herr_t _collect_tables_step(hid_t g_id, const char *name,
 	return 0;
 }
 
-static int _tables_list(hid_t fid_job, List tables)
+static int _tables_list(hid_t fid_job, list_t *tables)
 {
 	herr_t err;
 	list_itr_t *it;
@@ -1005,7 +1005,7 @@ static void _extract_totals(size_t nb_fields, size_t *offsets, hid_t *types,
  * Extract the content of a table within a node. This function first discovers
  * the content of the table and then handles both timeseries and totals levels.
  */
-static int _extract_series_table(hid_t fid_job, table_t *table, List fields,
+static int _extract_series_table(hid_t fid_job, table_t *table, list_t *fields,
 				 FILE *output, bool level_total)
 {
 	char path[PATH_MAX];
@@ -1136,8 +1136,8 @@ static int _extract_series(void)
 	hid_t fid_job = -1;
 	bool level_total;
 	const char *field;
-	List tables = NULL;
-	List fields = NULL;
+	list_t *tables = NULL;
+	list_t *fields = NULL;
 	list_itr_t *it;
 	FILE *output = NULL;
 	int rc = SLURM_ERROR;
@@ -1448,7 +1448,7 @@ static herr_t _extract_item_step(hid_t g_id, const char *step_name,
 	hid_t item_type = -1;
 	herr_t err;
 
-	List tables = NULL;
+	list_t *tables = NULL;
 	list_itr_t *it = NULL;
 	table_t *t;
 
@@ -1647,7 +1647,7 @@ static int _extract_item(void)
 	return SLURM_SUCCESS;
 }
 
-static int _fields_intersection(hid_t fid_job, List tables, List fields)
+static int _fields_intersection(hid_t fid_job, list_t *tables, list_t *fields)
 {
 	hid_t jgid_table = -1;
 	hid_t tid = -1;
@@ -1722,11 +1722,11 @@ static int _fields_intersection(hid_t fid_job, List tables, List fields)
 static int _list_items(void)
 {
 	hid_t fid_job = -1;
-	List fields;
+	list_t *fields;
 	list_itr_t *it;
 	const char *field;
 	int rc = SLURM_ERROR;
-	List tables;
+	list_t *tables;
 
 	/* get series names */
 	fid_job = H5Fopen(params.input, H5F_ACC_RDONLY, H5P_DEFAULT);
