@@ -246,7 +246,7 @@ again:
 		error("Munge encode failed: %s", munge_ctx_strerror(ctx));
 		xfree(cred);
 		cred = NULL;
-		slurm_seterrno(ESLURM_AUTH_CRED_INVALID);
+		errno = ESLURM_AUTH_CRED_INVALID;
 	} else if ((bad_cred_test > 0) && cred->m_str) {
 		/*
 		 * Avoid changing the trailing ':' character, or any of the
@@ -297,7 +297,7 @@ int auth_p_verify(auth_credential_t *c, char *opts)
 	char *socket;
 
 	if (!c) {
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return SLURM_ERROR;
 	}
 
@@ -354,7 +354,7 @@ char *auth_p_get_host(auth_credential_t *cred)
 		 * the calling path did not verify the credential first.
 		 */
 		xassert(!cred);
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return NULL;
 	}
 
@@ -377,8 +377,7 @@ char *auth_p_get_host(auth_credential_t *cred)
 	 * which will never resolve successfully. So don't even bother trying.
 	 */
 	if (sin->sin_addr.s_addr != 0) {
-		hostname = xgetnameinfo((struct sockaddr *) &addr,
-					sizeof(addr));
+		hostname = xgetnameinfo(&addr);
 		/*
 		 * The NI_NOFQDN flag was used here previously, but did not work
 		 * as desired if the primary domain did not match on both sides.
@@ -391,7 +390,7 @@ char *auth_p_get_host(auth_credential_t *cred)
 		/* at this point, the name lookup failed */
 		hostname = xmalloc(INET_ADDRSTRLEN);
 		slurm_get_ip_str(&addr, hostname, INET_ADDRSTRLEN);
-		if (!(slurm_conf.conf_flags & CTL_CONF_IPV6_ENABLED))
+		if (!(slurm_conf.conf_flags & CONF_FLAG_IPV6_ENABLED))
 			error("%s: Lookup failed for %s", __func__, hostname);
 	}
 
@@ -409,7 +408,7 @@ extern int auth_p_get_data(auth_credential_t *cred, char **data, uint32_t *len)
 		 * the calling path did not verify the credential first.
 		 */
 		xassert(!cred);
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return SLURM_ERROR;
 	}
 
@@ -429,7 +428,7 @@ extern int auth_p_get_data(auth_credential_t *cred, char **data, uint32_t *len)
 extern void *auth_p_get_identity(auth_credential_t *cred)
 {
 	if (!cred) {
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return NULL;
 	}
 
@@ -443,7 +442,7 @@ extern void *auth_p_get_identity(auth_credential_t *cred)
 int auth_p_pack(auth_credential_t *cred, buf_t *buf, uint16_t protocol_version)
 {
 	if (!cred || !buf) {
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return SLURM_ERROR;
 	}
 
@@ -467,10 +466,9 @@ int auth_p_pack(auth_credential_t *cred, buf_t *buf, uint16_t protocol_version)
 auth_credential_t *auth_p_unpack(buf_t *buf, uint16_t protocol_version)
 {
 	auth_credential_t *cred = NULL;
-	uint32_t size;
 
 	if (!buf) {
-		slurm_seterrno(ESLURM_AUTH_BADARG);
+		errno = ESLURM_AUTH_BADARG;
 		return NULL;
 	}
 
@@ -481,7 +479,7 @@ auth_credential_t *auth_p_unpack(buf_t *buf, uint16_t protocol_version)
 		cred->verified = false;
 		cred->m_xstr = true;
 
-		safe_unpackstr_xmalloc(&cred->m_str, &size, buf);
+		safe_unpackstr(&cred->m_str, buf);
 	} else {
 		error("%s: unknown protocol version %u",
 		      __func__, protocol_version);
@@ -491,7 +489,7 @@ auth_credential_t *auth_p_unpack(buf_t *buf, uint16_t protocol_version)
 	return cred;
 
 unpack_error:
-	slurm_seterrno(ESLURM_AUTH_UNPACK);
+	errno = ESLURM_AUTH_UNPACK;
 	auth_p_destroy(cred);
 	return NULL;
 }
@@ -556,7 +554,7 @@ again:
 			_print_cred(ctx);
 			if (err == EMUNGE_CRED_REWOUND)
 				error("Check for out of sync clocks");
-			slurm_seterrno(ESLURM_AUTH_CRED_INVALID);
+			errno = ESLURM_AUTH_CRED_INVALID;
 			goto done;
 #ifdef MULTIPLE_SLURMD
 		}
@@ -607,10 +605,9 @@ static void _print_cred(munge_ctx_t ctx)
 		info("DECODED: %s", slurm_ctime2_r(&decoded, buf));
 }
 
-
 /*
  * auth/munge does not support user aliasing. Only permit this call from the
- * same user (which means no internal state changes are necessary.
+ * same user (which means no internal state changes are necessary).
  */
 int auth_p_thread_config(const char *token, const char *username)
 {
@@ -647,3 +644,8 @@ char *auth_p_token_generate(const char *username, int lifespan)
 {
 	return NULL;
 }
+
+extern int auth_p_get_reconfig_fd(void)
+{
+	return -1;
+}
