@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  cgroup_common.c - Cgroup plugin common functions
  *****************************************************************************
- *  Copyright (C) 2021 SchedMD LLC
- *  Written by Felip Moll <felip.moll@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -40,6 +39,9 @@
 /* Testing read() on cgroup interfaces returns 4092 bytes at most. */
 #define CGROUP_READ_COUNT 4092
 
+/* How much to wait for a pid to be removed from one cgroup. */
+#define MAX_MOVE_WAIT 1000 /* Miliseconds */
+
 /* These are defined here so when we link with something other than
  * the slurmctld we will have these symbols defined.  They will get
  * overwritten when linking with the slurmctld.
@@ -463,6 +465,8 @@ extern void common_cgroup_ns_destroy(xcgroup_ns_t *cgns)
 	xfree(cgns->mnt_point);
 	xfree(cgns->mnt_args);
 	xfree(cgns->subsystems);
+	xfree(cgns->init_cg_path);
+	FREE_NULL_BITMAP(cgns->avail_controllers);
 }
 
 extern void common_cgroup_destroy(xcgroup_t *cg)
@@ -655,3 +659,54 @@ extern int common_cgroup_unlock(xcgroup_t *cg)
 	close(cg->fd);
 	return fstatus;
 }
+
+extern bool common_cgroup_wait_pid_moved(xcgroup_t *cg, pid_t pid,
+					 const char *cg_name)
+{
+	pid_t *pids = NULL;
+	int npids = 0;
+	int cnt = 0;
+	int i = 0;
+	bool found;
+
+	/*
+	 * There is a delay in the cgroup system when moving the pid from one
+	 * cgroup to another. This is usually short, but we need to wait to make
+	 * sure the pid is out of the step cgroup or we will occur an error
+	 * leaving the cgroup unable to be removed.
+	 *
+	 * The way it is implemented of checking whether the pid is in the
+	 * cgroup or not is not 100% reliable. In slow cgroup subsystems there
+	 * is the possibility that the internal kernel references are not
+	 * cleaned up even if the pid is not in the cgroup.procs anymore, in
+	 * that case we will receive an -EBUSY when trying to delete later the
+	 * cgroup. This is explained here:
+	 * https://bugs.schedmd.com/show_bug.cgi?id=8911#c18
+	 *
+	 * So try to mitigate this issue in a best-effort by waiting
+	 * MAX_MOVE_WAIT/10 milis when we find the pid, and retry 10 times.
+	 */
+	do {
+		cnt++;
+		common_cgroup_get_pids(cg, &pids, &npids);
+		found = false;
+		for (i = 0; i < npids; i++) {
+			if (pids[i] == pid) {
+				found = true;
+				poll(NULL, 0, MAX_MOVE_WAIT/10);
+				break;
+			}
+		}
+		xfree(pids);
+	}  while (found && (cnt < 10));
+
+	if (!found)
+		log_flag(CGROUP, "Took %d checks before pid %d was removed from the %s cgroup.",
+			 cnt, pid, cg_name);
+	else {
+		error("Pid %d is still in the %s cgroup after %d tries and %d ms.",
+		      pid, cg_name, cnt, MAX_MOVE_WAIT);
+		return false;
+	}
+	return true;
+}
