@@ -40,6 +40,28 @@
 #include "src/common/openapi.h"
 #include "src/interfaces/data_parser.h"
 
+/*
+ * Populate OpenAPI specification field with reference to parser
+ * IN obj - data_t ptr to specific field in OpenAPI schema
+ * 	Sets "$ref" key in obj to path of parser schema.
+ * 	Parser must be an OBJECT or ARRAY OpenAPI type.
+ * IN parser - populate field with $ref to parser
+ * IN spec - entire OpenAPI specification
+ * IN args - parser args
+ */
+extern void set_openapi_parse_ref(data_t *obj, const parser_t *parser,
+				  data_t *spec, args_t *args);
+
+/*
+ * Populate OpenAPI specification field
+ * IN obj - data_t ptr to specific field in OpenAPI schema
+ * IN format - OpenAPI format to use
+ * IN desc - Description of field to use
+ * RET ptr to "items" for ARRAY or "properties" for OBJECT or NULL
+ */
+extern data_t *set_openapi_props(data_t *obj, openapi_type_format_t format,
+				 const char *desc);
+
 /*
  * Populate dst with OpenAPI specification schema
  * IN dst - data_t ptr to populate with schema
