@@ -55,6 +55,7 @@ typedef enum {
 	FLAG_BIT_TYPE_INVALID = 0, /* aka not initialized */
 	FLAG_BIT_TYPE_EQUAL, /* entire masked value must match for flag */
 	FLAG_BIT_TYPE_BIT, /* only need bit(s) to match */
+	FLAG_BIT_TYPE_REMOVED, /* flag removed but needs to still parse correct */
 	FLAG_BIT_TYPE_MAX /* place holder */
 } flag_bit_type_t;
 
@@ -92,6 +93,14 @@ typedef enum {
 	/* NT_ARRAY objects must not require an special initializer */
 	PARSER_MODEL_NT_ARRAY, /* parser for NULL terminated array of objects */
 
+	/*
+	 * Alias for another parser.
+	 *
+	 * Only for use in maintaining the same OAS name when a new parser name
+	 * is needed in newer plugins.
+	 */
+	PARSER_MODEL_ALIAS,
+
 	PARSER_MODEL_MAX /* place holder */
 } parser_model_t;
 
@@ -123,6 +132,9 @@ typedef struct parser_s {
 	ssize_t ptr_offset; /* offset from parent object or NO_VAL */
 	bool required;
 
+	/* Alias model properties ----------------------------------------- */
+	type_t alias_type;
+
 	/* Pointer model properties ----------------------------------------- */
 	type_t pointer_type;
 	bool allow_null_pointer; /* leave destination as null type when source pointer is NULL while dumping */
@@ -205,6 +217,11 @@ extern void verify_parser_not_sliced_funcname(const parser_t *const parser,
 
 extern const parser_t *const find_parser_by_type(type_t type);
 
+/*
+ * Resolve aliased or pointer model parsers to final unaliased parser
+ */
+extern const parser_t *unalias_parser(const parser_t *parser);
+
 extern void get_parsers(const parser_t **parsers_ptr, int *count_ptr);
 
 #endif
