@@ -95,7 +95,7 @@ extern int data_parser_p_dump(args_t *args, data_parser_type_t type, void *src,
 		return ESLURM_NOT_SUPPORTED;
 	}
 
-	return dump(src, src_bytes, parser, dst, args);
+	return dump(src, src_bytes, NULL, parser, dst, args);
 }
 
 extern int data_parser_p_parse(args_t *args, data_parser_type_t type, void *dst,
@@ -139,15 +139,19 @@ static void _parse_param(const char *param, args_t *args)
 		if (xstrcasecmp(bit->name, param))
 			continue;
 
-		log_flag(DATA, "parser(0x%"PRIxPTR") activated flag=%s",
-			 (uintptr_t) args, bit->flag_name);
+		if (bit->value == FLAG_PREFER_REFS) {
+			info("%s ignoring default flag %s",
+			     plugin_type, bit->flag_name);
+			return;
+		}
+
+		debug("%s activated flag %s", plugin_type, bit->flag_name);
 
 		args->flags |= bit->value;
 		return;
 	}
 
-	log_flag(DATA, "parser(0x%"PRIxPTR") ignoring param=%s",
-		 (uintptr_t) args, param);
+	warning("%s ignoring unknown flag %s", plugin_type, param);
 }
 
 extern args_t *data_parser_p_new(data_parser_on_error_t on_parse_error,
@@ -269,16 +273,17 @@ extern openapi_type_t data_parser_p_resolve_openapi_type(
 	if (!parser)
 		return OPENAPI_TYPE_INVALID;
 
+	if (parser->model == PARSER_MODEL_ALIAS)
+		return openapi_type_format_to_type(unalias_parser(
+			find_parser_by_type(parser->type))->obj_openapi);
+
 	if (!field)
 		return openapi_type_format_to_type(parser->obj_openapi);
 
 	for (int i = 0; i < parser->field_count; i++) {
 		if (!xstrcasecmp(parser->fields[i].field_name, field)) {
-			const parser_t *p =
-				find_parser_by_type(parser->fields[i].type);
-
-			while (p->pointer_type)
-				p = find_parser_by_type(p->pointer_type);
+			const parser_t *p = unalias_parser(
+				find_parser_by_type(parser->fields[i].type));
 
 			return openapi_type_format_to_type(p->obj_openapi);
 		}
@@ -297,8 +302,7 @@ extern const char *data_parser_p_resolve_type_string(args_t *args,
 	if (!parser)
 		return NULL;
 
-	while (parser->pointer_type)
-		parser = find_parser_by_type(parser->pointer_type);
+	parser = unalias_parser(parser);
 
 	return parser->type_string;
 }
