@@ -70,7 +70,7 @@
 #include "src/common/log.h"
 #include "src/common/net.h"
 #include "src/common/read_config.h"
-#include "src/common/slurm_mpi.h"
+#include "src/interfaces/mpi.h"
 #include "src/common/slurm_protocol_api.h"
 #include "src/common/strlcpy.h"
 #include "src/common/xassert.h"
