@@ -125,7 +125,7 @@ static void recv_handle(void *request, ucs_status_t status,
 }
 
 static bool _epoll_readable(eio_obj_t *obj);
-static int _epoll_read(eio_obj_t *obj, List objs);
+static int _epoll_read(eio_obj_t *obj, list_t *objs);
 
 static struct io_operations _epoll_ops = {
 	.readable = _epoll_readable,
@@ -133,7 +133,7 @@ static struct io_operations _epoll_ops = {
 };
 
 static bool _progress_readable(eio_obj_t *obj);
-static int _progress_read(eio_obj_t *obj, List objs);
+static int _progress_read(eio_obj_t *obj, list_t *objs);
 
 static struct io_operations _progress_ops = {
 	.readable = _progress_readable,
@@ -169,7 +169,7 @@ static int _load_ucx_lib()
 	 * we have from autoconf
 	 */
 	char *full_path = NULL;
-	xstrfmtcat(full_path, "%s/libucp.so", PMIXP_UCX_LIBPATH);
+	xstrfmtcat(full_path, "%s/libucp.so.0", PMIXP_UCX_LIBPATH);
 	_ucx_lib_handler = dlopen(full_path, RTLD_LAZY | RTLD_GLOBAL);
 	xfree(full_path);
 	if (_ucx_lib_handler) {
@@ -180,7 +180,7 @@ static int _load_ucx_lib()
 	 * known by dynamic linker.
 	 */
 #endif
-	_ucx_lib_handler = dlopen("libucp.so", RTLD_LAZY | RTLD_GLOBAL);
+	_ucx_lib_handler = dlopen("libucp.so.0", RTLD_LAZY | RTLD_GLOBAL);
 	if (!_ucx_lib_handler) {
 		char *err = dlerror();
 		PMIXP_ERROR("Cannot open UCX lib: %s", (err) ? err : "unknown");
@@ -273,6 +273,11 @@ int pmixp_dconn_ucx_prepare(pmixp_dconn_handlers_t *handlers,
 		goto err_efd;
 	}
 
+	if (pipe(_service_pipe) != 0) {
+		PMIXP_ERROR("Failed to open service pipe: %m");
+		goto err_pipe;
+	}
+
 	memset(handlers, 0, sizeof(*handlers));
 	handlers->connect = _ucx_connect;
 	handlers->init = _ucx_init;
@@ -286,6 +291,7 @@ int pmixp_dconn_ucx_prepare(pmixp_dconn_handlers_t *handlers,
 
 	return SLURM_SUCCESS;
 
+err_pipe:
 err_efd:
 	ucp_worker_release_address(ucp_worker, _ucx_addr);
 err_addr:
@@ -390,7 +396,7 @@ void _ucx_process_msg(char *buffer, size_t len)
 	xassert(_direct_hdr_set);
 	_direct_hdr.hdr_unpack_cb(buffer, _host_hdr);
 
-	Buf buf = create_buf(buffer, len);
+	buf_t *buf = create_buf(buffer, len);
 	set_buf_offset(buf, _direct_hdr.rhdr_net_size);
 	_direct_hdr.new_msg(_host_hdr, buf);
 }
@@ -562,7 +568,7 @@ static bool _epoll_readable(eio_obj_t *obj)
 	return true;
 }
 
-static int _epoll_read(eio_obj_t *obj, List objs)
+static int _epoll_read(eio_obj_t *obj, list_t *objs)
 {
 	if (obj->shutdown) {
 		/* corresponding connection will be
@@ -591,7 +597,7 @@ static bool _progress_readable(eio_obj_t *obj)
 	return true;
 }
 
-static int _progress_read(eio_obj_t *obj, List objs)
+static int _progress_read(eio_obj_t *obj, list_t *objs)
 {
 	char buf;
 
@@ -761,10 +767,6 @@ static void _ucx_regio(eio_handle_t *h)
 {
 	eio_obj_t *obj;
 
-	if (pipe(_service_pipe) != 0) {
-		error("pipe(): %m");
-		return;
-	}
 	fd_set_nonblocking(_service_pipe[0]);
 	fd_set_nonblocking(_service_pipe[1]);
 	fd_set_close_on_exec(_service_pipe[0]);
