@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  serializer_json.c - Serializer for JSON.
  *****************************************************************************
- *  Copyright (C) 2021 SchedMD LLC
- *  Written by Nathan Rini <nate@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -221,7 +220,7 @@ static json_object *_data_to_json(const data_t *d)
 	}
 	case DATA_TYPE_STRING:
 	{
-		const char *str = data_get_string_const(d);
+		const char *str = data_get_string(d);
 		if (str)
 			return json_object_new_string(str);
 		else
