@@ -44,15 +44,16 @@ extern int task_cgroup_devices_init(void);
 extern int task_cgroup_devices_fini(void);
 
 /* create user/job/jobstep devices cgroups */
-extern int task_cgroup_devices_create(stepd_step_rec_t *job);
+extern int task_cgroup_devices_create(stepd_step_rec_t *step);
 
 /* add a task to the devices cgroup */
-extern int task_cgroup_devices_add_pid(stepd_step_rec_t *job, pid_t pid,
+extern int task_cgroup_devices_add_pid(stepd_step_rec_t *step, pid_t pid,
 				       uint32_t taskid);
 
 /* constrain the devices in the task */
-extern int task_cgroup_devices_constrain(stepd_step_rec_t *job, pid_t pid,
-				         uint32_t taskid);
+extern int task_cgroup_devices_constrain(stepd_step_rec_t *step,
+					 uint32_t node_tid,
+					 uint32_t global_tid);
 
 /* add a pid to the extern step devices cgroup */
 extern int task_cgroup_devices_add_extern_pid(pid_t pid);
