@@ -119,6 +119,11 @@ extern int topology_p_whole_topo(bitstr_t *node_mask)
 	return SLURM_SUCCESS;
 }
 
+extern bitstr_t *topology_p_get_bitmap(char *name)
+{
+	return NULL;
+}
+
 /*
  * topo_generate_node_ranking  -  populate node_rank fields
  */
@@ -175,3 +180,8 @@ extern int topology_p_topology_unpack(void **topoinfo_pptr, buf_t *buffer,
 {
 	return SLURM_SUCCESS;
 }
+
+extern uint32_t topology_p_get_fragmentation(bitstr_t *node_mask)
+{
+	return 0;
+}
