@@ -39,6 +39,7 @@
 #include "sacct.h"
 #include "src/common/cpu_frequency.h"
 #include "src/common/parse_time.h"
+#include "src/common/print_fields.h"
 #include "src/common/uid.h"
 #include "slurm/slurm.h"
 
@@ -87,7 +88,7 @@ static char *_elapsed_time(uint64_t secs, uint64_t usecs)
 	return str;
 }
 
-static char *_find_qos_name_from_list(List qos_list, int qosid)
+static char *_find_qos_name_from_list(list_t *qos_list, int qosid)
 {
 	slurmdb_qos_rec_t *qos;
 
@@ -278,6 +279,38 @@ static void _print_expanded_array_job(slurmdb_job_rec_t *job)
 	FREE_NULL_BITMAP(bitmap);
 }
 
+static void _expand_stdio_patterns(slurmdb_job_rec_t *job)
+{
+	char *tmp_path;
+	job_std_pattern_t job_stp;
+	slurmdb_step_rec_t *step = job->first_step_ptr;
+
+	job_stp.array_job_id = job->array_job_id;
+	job_stp.array_task_id = job->array_task_id;
+	job_stp.first_step_name = step ? step->stepname : NULL;
+	job_stp.first_step_node = step ? step->nodes : NULL;
+	job_stp.jobid = job->jobid;
+	job_stp.jobname = job->jobname;
+	job_stp.user = job->user;
+	job_stp.work_dir = job->work_dir;
+
+	if (job->std_in && (*job->std_in != '\0')) {
+		tmp_path = expand_stdio_fields(job->std_in, &job_stp);
+		xfree(job->std_in);
+		job->std_in = tmp_path;
+	}
+	if (job->std_err && (*job->std_err != '\0')) {
+		tmp_path = expand_stdio_fields(job->std_err, &job_stp);
+		xfree(job->std_err);
+		job->std_err = tmp_path;
+	}
+	if (job->std_out && (*job->std_out != '\0')) {
+		tmp_path = expand_stdio_fields(job->std_out, &job_stp);
+		xfree(job->std_out);
+		job->std_out = tmp_path;
+	}
+}
+
 extern void print_fields(type_t type, void *object)
 {
 	slurmdb_job_rec_t *job = (slurmdb_job_rec_t *)object;
@@ -301,6 +334,8 @@ extern void print_fields(type_t type, void *object)
 
 	switch (type) {
 	case JOB:
+		if (params.expand_patterns)
+			_expand_stdio_patterns(job);
 		job_comp = NULL;
 		cpu_tres_rec_count = slurmdb_find_tres_count_in_string(
 			job->tres_alloc_str,
@@ -344,6 +379,7 @@ extern void print_fields(type_t type, void *object)
 						    confirm the values
 						    coming in are
 						    NO_VAL64 */
+		uint16_t tmp_uint16 = NO_VAL16;
 		uint32_t tmp_uint32 = NO_VAL, tmp2_uint32 = NO_VAL;
 		uint64_t tmp_uint64 = NO_VAL64, tmp2_uint64 = NO_VAL64;
 
@@ -705,6 +741,7 @@ extern void print_fields(type_t type, void *object)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_DB_INX:
+		case PRINT_SLUID:
 			switch(type) {
 			case JOB:
 				tmp_uint64 = job->db_index;
@@ -907,17 +944,17 @@ extern void print_fields(type_t type, void *object)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_GROUP:
+			tmp_char = NULL;
 			switch(type) {
 			case JOB:
-				tmp_uint32 = job->gid;
+				tmp_char = gid_to_string(job->gid);
 				break;
 			case JOBCOMP:
-				tmp_uint32 = job_comp->gid;
+				tmp_char = gid_to_string(job_comp->gid);
 				break;
 			default:
 				break;
 			}
-			tmp_char = gid_to_string(tmp_uint32);
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
@@ -1523,10 +1560,10 @@ extern void print_fields(type_t type, void *object)
 			case JOB:
 				tmp_int = job->qosid;
 				if (!g_qos_list) {
-					slurmdb_qos_cond_t qos_cond;
-					memset(&qos_cond, 0,
-					       sizeof(slurmdb_qos_cond_t));
-					qos_cond.with_deleted = 1;
+					slurmdb_qos_cond_t qos_cond = {
+						.flags =
+						QOS_COND_FLAG_WITH_DELETED,
+					};
 					g_qos_list = slurmdb_qos_get(
 						acct_db_conn, &qos_cond);
 				}
@@ -1556,10 +1593,22 @@ extern void print_fields(type_t type, void *object)
 					     &tmp_uint32,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_QOSREQ:
+			switch(type) {
+			case JOB:
+				tmp_char = job->qos_req;
+				break;
+			default:
+				break;
+			}
+			field->print_routine(field,
+					     tmp_char,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_REASON:
 			switch(type) {
 			case JOB:
-				tmp_char = job_reason_string(
+				tmp_char = (char *) job_state_reason_string(
 					job->state_reason_prev);
 				break;
 			default:
@@ -1709,6 +1758,18 @@ extern void print_fields(type_t type, void *object)
 					     &tmp_uint32,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_RESTART_CNT:
+			switch(type) {
+			case JOB:
+				tmp_uint16 = job->restart_cnt;
+				break;
+			default:
+				break;
+			}
+			field->print_routine(field,
+					     &tmp_uint16,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_PLANNED:
 			/*
 			 * If eligible is 0 or -1, then the job was never
@@ -1843,6 +1904,48 @@ extern void print_fields(type_t type, void *object)
 					     outbuf,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_STDERR:
+			switch(type) {
+			case JOB:
+				tmp_char = job->std_err;
+				break;
+			case JOBSTEP:
+			case JOBCOMP:
+			default:
+				tmp_char = NULL;
+				break;
+			}
+			field->print_routine(field, tmp_char,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_STDIN:
+			switch(type) {
+			case JOB:
+				tmp_char = job->std_in;
+				break;
+			case JOBSTEP:
+			case JOBCOMP:
+			default:
+				tmp_char = NULL;
+				break;
+			}
+			field->print_routine(field, tmp_char,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_STDOUT:
+			switch(type) {
+			case JOB:
+				tmp_char = job->std_out;
+				break;
+			case JOBSTEP:
+			case JOBCOMP:
+			default:
+				tmp_char = NULL;
+				break;
+			}
+			field->print_routine(field, tmp_char,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_SUBMIT:
 			switch(type) {
 			case JOB:
