@@ -67,7 +67,7 @@ print_field_t fields[] = {
 	{19, "Container", print_fields_str, PRINT_CONTAINER},
 	{10, "CPUTime", print_fields_time_from_secs, PRINT_CPU_TIME},
 	{10, "CPUTimeRAW", print_fields_uint64, PRINT_CPU_TIME_RAW},
-	{-10, "DBIndex", print_fields_uint64, PRINT_DB_INX},
+	{-21, "DBIndex", print_fields_uint64, PRINT_DB_INX},
 	{15, "DerivedExitCode", print_fields_str, PRINT_DERIVED_EC},
 	{10, "Elapsed", print_fields_time_from_secs, PRINT_ELAPSED},
 	{10, "ElapsedRaw", print_fields_uint32, PRINT_ELAPSED_RAW},
@@ -114,6 +114,7 @@ print_field_t fields[] = {
 	{10, "Priority", print_fields_uint, PRINT_PRIO},
 	{10, "QOS", print_fields_str, PRINT_QOS},
 	{6,  "QOSRAW", print_fields_uint, PRINT_QOSRAW},
+	{10, "QOSREQ", print_fields_str, PRINT_QOSREQ},
 	{22, "Reason", print_fields_str, PRINT_REASON},
 	{10, "ReqCPUFreq", print_fields_str, PRINT_REQ_CPUFREQ_MAX}, /* vestigial */
 	{13, "ReqCPUFreqGov", print_fields_str, PRINT_REQ_CPUFREQ_GOV},
@@ -125,8 +126,13 @@ print_field_t fields[] = {
 	{10, "ReqTRES", print_fields_str, PRINT_TRESR},
 	{20, "Reservation",  print_fields_str, PRINT_RESERVATION},
 	{8,  "ReservationId",  print_fields_uint, PRINT_RESERVATION_ID},
+	{8,  "Restarts", print_fields_uint16, PRINT_RESTART_CNT},
+	{14, "SLUID", print_fields_sluid, PRINT_SLUID},
 	{19, "Start", print_fields_date, PRINT_START},
 	{10, "State", print_fields_str, PRINT_STATE},
+	{20, "StdErr", print_fields_str, PRINT_STDERR},
+	{20, "StdIn", print_fields_str, PRINT_STDIN},
+	{20, "StdOut", print_fields_str, PRINT_STDOUT},
 	{19, "Submit", print_fields_date, PRINT_SUBMIT},
 	{20, "SubmitLine", print_fields_str, PRINT_SUBMIT_LINE},
 	{10, "Suspended", print_fields_time_from_secs, PRINT_SUSPENDED},
@@ -160,7 +166,7 @@ print_field_t fields[] = {
 	{0,  NULL, NULL, 0}
 };
 
-List jobs = NULL;
+list_t *jobs = NULL;
 
 int main(int argc, char **argv)
 {
@@ -210,8 +216,7 @@ int main(int argc, char **argv)
 	sacct_fini();
 
 #if MEMORY_LEAK_DEBUG
-	auth_g_fini();
-	slurm_conf_destroy();
+	slurm_fini();
 	log_fini();
 #endif
 
