@@ -44,7 +44,7 @@
 
 static int _set_cond(int *start, int argc, char **argv,
 		     slurmdb_account_cond_t *acct_cond,
-		     List format_list)
+		     list_t *format_list)
 {
 	int i;
 	int cond_set = 0;
@@ -84,23 +84,23 @@ static int _set_cond(int *start, int argc, char **argv,
 		} else if (!end &&
 			   !xstrncasecmp(argv[i], "WithAssoc",
 					 MAX(command_len, 5))) {
-			acct_cond->with_assocs = 1;
+			acct_cond->flags |= SLURMDB_ACCT_FLAG_WASSOC;
 		} else if (!end &&
 			   !xstrncasecmp(argv[i], "WithCoordinators",
 					 MAX(command_len, 5))) {
-			acct_cond->with_coords = 1;
+			acct_cond->flags |= SLURMDB_ACCT_FLAG_WCOORD;
 		} else if (!end &&
 			   !xstrncasecmp(argv[i], "WithDeleted",
 					 MAX(command_len, 5))) {
-			acct_cond->with_deleted = 1;
-			assoc_cond->with_deleted = 1;
+			acct_cond->flags |= SLURMDB_ACCT_FLAG_DELETED;
+			assoc_cond->flags |= ASSOC_COND_FLAG_WITH_DELETED;
 		} else if (!end &&
 			   !xstrncasecmp(argv[i], "WithRawQOSLevel",
 					 MAX(command_len, 5))) {
-			assoc_cond->with_raw_qos = 1;
+			assoc_cond->flags |= ASSOC_COND_FLAG_RAW_QOS;
 		} else if (!end && !xstrncasecmp(argv[i], "WOPLimits",
 						 MAX(command_len, 4))) {
-			assoc_cond->without_parent_limits = 1;
+			assoc_cond->flags |= ASSOC_COND_FLAG_WOPL;
 		} else if (!end && !xstrncasecmp(argv[i], "where",
 					       MAX(command_len, 5))) {
 			continue;
@@ -127,8 +127,13 @@ static int _set_cond(int *start, int argc, char **argv,
 			if (slurm_addto_char_list(acct_cond->description_list,
 						 argv[i]+end))
 				cond_set |= SA_SET_USER;
+		} else if (!xstrncasecmp(argv[i], "Flags",
+					 MAX(command_len, 2))) {
+			acct_cond->flags |= str_2_slurmdb_acct_flags(
+				argv[i]+end);
+			cond_set |= SA_SET_USER;
 		} else if (!xstrncasecmp(argv[i], "Format",
-					 MAX(command_len, 1))) {
+					 MAX(command_len, 2))) {
 			if (format_list)
 				slurm_addto_char_list(format_list, argv[i]+end);
 		} else if (!xstrncasecmp(argv[i], "Organizations",
@@ -158,8 +163,8 @@ static int _set_cond(int *start, int argc, char **argv,
 }
 
 static int _set_rec(int *start, int argc, char **argv,
-		    List acct_list,
-		    List cluster_list,
+		    list_t *acct_list,
+		    list_t *cluster_list,
 		    slurmdb_account_rec_t *acct,
 		    slurmdb_assoc_rec_t *assoc)
 {
@@ -221,6 +226,10 @@ static int _set_rec(int *start, int argc, char **argv,
 			acct->description =  strip_quotes(argv[i]+end, NULL, 1);
 			rec_set |= SA_SET_USER;
 
+		} else if (!xstrncasecmp(argv[i], "Flags",
+					 MAX(command_len, 2))) {
+			acct->flags = str_2_slurmdb_acct_flags(argv[i]+end);
+			rec_set |= SA_SET_USER;
 		} else if (!xstrncasecmp(argv[i], "Organization",
 					 MAX(command_len, 1))) {
 			acct->organization = strip_quotes(argv[i]+end, NULL, 1);
@@ -338,10 +347,10 @@ extern int sacctmgr_list_account(int argc, char **argv)
 	int rc = SLURM_SUCCESS;
 	slurmdb_account_cond_t *acct_cond =
 		xmalloc(sizeof(slurmdb_account_cond_t));
- 	List acct_list;
+	list_t *acct_list;
 	int i=0, cond_set=0, prev_set=0;
-	ListIterator itr = NULL;
-	ListIterator itr2 = NULL;
+	list_itr_t *itr = NULL;
+	list_itr_t *itr2 = NULL;
 	slurmdb_account_rec_t *acct = NULL;
 	slurmdb_assoc_rec_t *assoc = NULL;
 	char *tmp_char = NULL;
@@ -351,10 +360,11 @@ extern int sacctmgr_list_account(int argc, char **argv)
 
 	print_field_t *field = NULL;
 
-	List format_list = list_create(xfree_ptr);
-	List print_fields_list; /* types are of print_field_t */
+	list_t *format_list = list_create(xfree_ptr);
+	list_t *print_fields_list; /* types are of print_field_t */
 
-	acct_cond->with_assocs = with_assoc_flag;
+	if (with_assoc_flag)
+		acct_cond->flags |= SLURMDB_ACCT_FLAG_WASSOC;
 
 	for (i=0; i<argc; i++) {
 		int command_len = strlen(argv[i]);
@@ -371,7 +381,7 @@ extern int sacctmgr_list_account(int argc, char **argv)
 		return SLURM_ERROR;
 	} else if (!list_count(format_list)) {
 		slurm_addto_char_list(format_list, "Acc,Des,O");
-		if (acct_cond->with_assocs)
+		if (acct_cond->flags & SLURMDB_ACCT_FLAG_WASSOC)
 			slurm_addto_char_list(format_list,
 					      "Cl,ParentN,U,Share,Priority,"
 					      "GrpJ,GrpN,"
@@ -379,12 +389,13 @@ extern int sacctmgr_list_account(int argc, char **argv)
 					      "MaxJ,MaxN,MaxCPUs,MaxS,MaxW,"
 					      "MaxCPUMins,QOS,DefaultQOS");
 
-		if (acct_cond->with_coords)
+		if (acct_cond->flags & SLURMDB_ACCT_FLAG_WCOORD)
 			slurm_addto_char_list(format_list, "Coord");
 
 	}
 
-	if (!acct_cond->with_assocs && (cond_set & SA_SET_ASSOC)) {
+	if (!(acct_cond->flags & SLURMDB_ACCT_FLAG_WASSOC) &&
+	    (cond_set & SA_SET_ASSOC)) {
 		if (!commit_check("You requested options that are only valid "
 				 "when querying with the withassoc option.\n"
 				 "Are you sure you want to continue?")) {
@@ -430,7 +441,7 @@ extern int sacctmgr_list_account(int argc, char **argv)
 
 	while((acct = list_next(itr))) {
 		if (acct->assoc_list) {
-			ListIterator itr3 =
+			list_itr_t *itr3 =
 				list_iterator_create(acct->assoc_list);
 			while((assoc = list_next(itr3))) {
 				int curr_inx = 1;
@@ -508,6 +519,14 @@ extern int sacctmgr_list_account(int argc, char **argv)
 						(curr_inx ==
 						 field_count));
 					break;
+				case PRINT_FLAGS:
+					tmp_char = slurmdb_acct_flags_2_str(
+						acct->flags);
+					field->print_routine(
+						field, tmp_char,
+						(curr_inx == field_count));
+					xfree(tmp_char);
+					break;
 				case PRINT_ORG:
 					field->print_routine(
 						field, acct->organization,
@@ -553,7 +572,7 @@ extern int sacctmgr_modify_account(int argc, char **argv)
 
 	int i=0;
 	int cond_set = 0, prev_set = 0, rec_set = 0, set = 0;
-	List ret_list = NULL;
+	list_t *ret_list = NULL;
 
 	slurmdb_init_assoc_rec(assoc, 0);
 
@@ -625,7 +644,7 @@ extern int sacctmgr_modify_account(int argc, char **argv)
 			db_conn, acct_cond, acct);
 		if (ret_list && list_count(ret_list)) {
 			char *object = NULL;
-			ListIterator itr = list_iterator_create(ret_list);
+			list_itr_t *itr = list_iterator_create(ret_list);
 			printf(" Modified accounts...\n");
 			while((object = list_next(itr))) {
 				printf("  %s\n", object);
@@ -663,7 +682,7 @@ assoc_start:
 
 		if (ret_list && list_count(ret_list)) {
 			char *object = NULL;
-			ListIterator itr = list_iterator_create(ret_list);
+			list_itr_t *itr = list_iterator_create(ret_list);
 			printf(" Modified account associations...\n");
 			while ((object = list_next(itr))) {
 				printf("  %s\n", object);
@@ -720,8 +739,8 @@ extern int sacctmgr_delete_account(int argc, char **argv)
 	slurmdb_account_cond_t *acct_cond =
 		xmalloc(sizeof(slurmdb_account_cond_t));
 	int i = 0;
-	List ret_list = NULL;
-	ListIterator itr = NULL;
+	list_t *ret_list = NULL;
+	list_itr_t *itr = NULL;
 	int cond_set = 0, prev_set = 0;
 
 	for (i = 0; i < argc; i++) {
@@ -775,7 +794,7 @@ extern int sacctmgr_delete_account(int argc, char **argv)
 		}
 	}
 
-	acct_cond->assoc_cond->only_defs = 0;
+	acct_cond->assoc_cond->flags &= ~ASSOC_COND_FLAG_ONLY_DEFS;;
 
 	notice_thread_init();
 	if (cond_set == SA_SET_USER) {
@@ -791,7 +810,7 @@ extern int sacctmgr_delete_account(int argc, char **argv)
 
 	if (ret_list && list_count(ret_list)) {
 		char *object = NULL;
-		ListIterator itr = NULL;
+		list_itr_t *itr = NULL;
 		itr = list_iterator_create(ret_list);
 
 		/* Check to see if person is trying to remove a default
