@@ -108,14 +108,13 @@ static pid_t _fork_command(char **command);
 static void _forward_signal(int signo);
 static void _job_complete_handler(srun_job_complete_msg_t *msg);
 static void _job_suspend_handler(suspend_msg_t *msg);
-static void _match_job_name(job_desc_msg_t *desc_last, List job_req_list);
+static void _match_job_name(job_desc_msg_t *desc_last, list_t *job_req_list);
 static void _node_fail_handler(srun_node_fail_msg_t *msg);
 static void _pending_callback(uint32_t job_id);
 static int  _proc_alloc(resource_allocation_response_msg_t *alloc);
 static void _ring_terminal_bell(void);
 static int  _set_cluster_name(void *x, void *arg);
 static void _set_exit_code(void);
-static void _set_rlimits(char **env);
 static void _set_spank_env(void);
 static void _set_submit_dir_env(void);
 static void _signal_while_allocating(int signo);
@@ -162,10 +161,9 @@ static int _copy_other_port(void *x, void *arg)
 
 int main(int argc, char **argv)
 {
-	static bool env_cache_set = false;
 	log_options_t logopt = LOG_OPTS_STDERR_ONLY;
 	job_desc_msg_t *desc = NULL, *first_job = NULL;
-	List job_req_list = NULL, job_resp_list = NULL;
+	list_t *job_req_list = NULL, *job_resp_list = NULL;
 	resource_allocation_response_msg_t *alloc = NULL;
 	time_t before, after;
 	allocation_msg_thread_t *msg_thr = NULL;
@@ -245,31 +243,6 @@ int main(int argc, char **argv)
 		} else if (work_dir)
 			opt.chdir = work_dir;
 
-		if ((opt.get_user_env_time >= 0) && !env_cache_set) {
-			bool no_env_cache = false;
-			char *user;
-
-			env_cache_set = true;
-			if (!(user = uid_to_string_or_null(opt.uid))) {
-				error("Invalid user id %u: %m",
-				      (uint32_t) opt.uid);
-				exit(error_exit);
-			}
-
-			if (xstrcasestr(slurm_conf.sched_params,
-					"no_env_cache"))
-				no_env_cache = true;
-
-			env = env_array_user_default(user,
-						     opt.get_user_env_time,
-						     opt.get_user_env_mode,
-						     no_env_cache);
-			xfree(user);
-			if (env == NULL)
-				exit(error_exit);    /* error already logged */
-			_set_rlimits(env);
-		}
-
 		if (desc && !job_req_list) {
 			job_req_list = list_create(NULL);
 			list_append(job_req_list, desc);
@@ -630,7 +603,7 @@ relinquish:
 
 		info("Relinquishing job allocation %u", my_job_id);
 		if ((slurm_complete_job(my_job_id, status) != 0) &&
-		    (slurm_get_errno() != ESLURM_ALREADY_DONE))
+		    (errno != ESLURM_ALREADY_DONE))
 			error("Unable to clean up job allocation %u: %m",
 			      my_job_id);
 		slurm_mutex_lock(&allocation_state_lock);
@@ -676,8 +649,7 @@ relinquish:
 #ifdef MEMORY_LEAK_DEBUG
 	cli_filter_fini();
 	slurm_reset_all_options(&opt, false);
-	auth_g_fini();
-	slurm_conf_destroy();
+	slurm_fini();
 	log_fini();
 #endif /* MEMORY_LEAK_DEBUG */
 
@@ -695,11 +667,29 @@ static int _proc_alloc(resource_allocation_response_msg_t *alloc)
 		slurm_setup_remote_working_cluster(alloc);
 
 		/* set env for srun's to find the right cluster */
-		setenvf(NULL, "SLURM_WORKING_CLUSTER", "%s:%s:%d:%d",
-			working_cluster_rec->name,
-			working_cluster_rec->control_host,
-			working_cluster_rec->control_port,
-			working_cluster_rec->rpc_version);
+		if (xstrstr(working_cluster_rec->control_host, ":")) {
+			/*
+			 * If the control_host has ':'s then it's an ipv6
+			 * address and need to be wrapped with "[]" because
+			 * SLURM_WORKING_CLUSTER is ':' delimited. In 24.11+,
+			 * _setup_env_working_cluster() handles this new format.
+			 */
+			setenvf(NULL, "SLURM_WORKING_CLUSTER", "%s:[%s]:%d:%d",
+				working_cluster_rec->name,
+				working_cluster_rec->control_host,
+				working_cluster_rec->control_port,
+				working_cluster_rec->rpc_version);
+		} else {
+			/*
+			 * Remove three versions after 24.11 and always use
+			 * the "[]" wrapped format and remove the above comment.
+			 */
+			setenvf(NULL, "SLURM_WORKING_CLUSTER", "%s:%s:%d:%d",
+				working_cluster_rec->name,
+				working_cluster_rec->control_host,
+				working_cluster_rec->control_port,
+				working_cluster_rec->rpc_version);
+		}
 	}
 
 	if (!_wait_nodes_ready(alloc)) {
@@ -715,7 +705,7 @@ static int _proc_alloc(resource_allocation_response_msg_t *alloc)
 /* Copy job name from last component to all hetjob components unless
  * explicitly set. The default value comes from _salloc_default_command()
  * and is "sh". */
-static void _match_job_name(job_desc_msg_t *desc_last, List job_req_list)
+static void _match_job_name(job_desc_msg_t *desc_last, list_t *job_req_list)
 {
 	list_itr_t *iter;
 	job_desc_msg_t *desc = NULL;
@@ -1014,47 +1004,6 @@ static void _node_fail_handler(srun_node_fail_msg_t *msg)
 	error("Node failure on %s", msg->nodelist);
 }
 
-static void _set_rlimits(char **env)
-{
-	slurm_rlimits_info_t *rli;
-	char env_name[32] = "SLURM_RLIMIT_";
-	char *env_value, *p;
-	struct rlimit r;
-	rlim_t env_num;
-	int header_len = sizeof("SLURM_RLIMIT_");
-
-	for (rli = get_slurm_rlimits_info(); rli->name; rli++) {
-		if (rli->propagate_flag != PROPAGATE_RLIMITS)
-			continue;
-		if ((header_len + strlen(rli->name)) >= sizeof(env_name)) {
-			error("%s: env_name(%s) too long", __func__, env_name);
-			continue;
-		}
-		strcpy(&env_name[header_len - 1], rli->name);
-		env_value = getenvp(env, env_name);
-		if (env_value == NULL)
-			continue;
-		unsetenvp(env, env_name);
-		if (getrlimit(rli->resource, &r) < 0) {
-			error("getrlimit(%s): %m", env_name+6);
-			continue;
-		}
-		env_num = strtol(env_value, &p, 10);
-		if (p && (p[0] != '\0')) {
-			error("Invalid environment %s value %s",
-			      env_name, env_value);
-			continue;
-		}
-		if (r.rlim_cur == env_num)
-			continue;
-		r.rlim_cur = (rlim_t) env_num;
-		if (setrlimit(rli->resource, &r) < 0) {
-			error("setrlimit(%s): %m", env_name+6);
-			continue;
-		}
-	}
-}
-
 /* returns 1 if job and nodes are ready for job to begin, 0 otherwise */
 static int _wait_nodes_ready(resource_allocation_response_msg_t *alloc)
 {
@@ -1109,8 +1058,7 @@ static int _wait_nodes_ready(resource_allocation_response_msg_t *alloc)
 		}
 	}
 	if (is_ready) {
-		if (i > 1)
-     			info("Nodes %s are ready for job", alloc->node_list);
+		info("Nodes %s are ready for job", alloc->node_list);
 	} else if (!allocation_interrupted) {
 		if (job_killed || allocation_revoked) {
 			error("Job allocation %u has been revoked",
