@@ -63,7 +63,7 @@
 
 /* Global externs from scontrol.h */
 char *command_name;
-List clusters = NULL;
+list_t *clusters = NULL;
 char *cluster_names = NULL;
 int all_flag = 0;	/* display even hidden partitions */
 int detail_flag = 0;	/* display additional details */
@@ -309,6 +309,14 @@ int main(int argc, char **argv)
 	FREE_NULL_LIST(clusters);
 	slurm_conf_destroy();
 	serializer_g_fini();
+
+	slurm_free_front_end_info_msg(old_front_end_info_ptr);
+	slurm_free_job_info_msg(old_job_info_ptr);
+	slurm_free_node_info_msg(old_node_info_ptr);
+	slurm_free_partition_info_msg(old_part_info_ptr);
+	slurm_free_reservation_info_msg(old_res_info_ptr);
+	slurm_free_ctl_conf(old_slurm_ctl_conf_ptr);
+
 #endif /* MEMORY_LEAK_DEBUG */
 
 	exit(exit_code);
@@ -450,7 +458,7 @@ static void _write_config(char *file_name)
 				&slurm_ctl_conf_ptr);
 		if (error_code == SLURM_SUCCESS) {
 			slurm_free_ctl_conf(old_slurm_ctl_conf_ptr);
-		} else if (slurm_get_errno () == SLURM_NO_CHANGE_IN_DATA) {
+		} else if (errno == SLURM_NO_CHANGE_IN_DATA) {
 			slurm_ctl_conf_ptr = old_slurm_ctl_conf_ptr;
 			error_code = SLURM_SUCCESS;
 			if (quiet_flag == -1) {
@@ -515,13 +523,20 @@ static void _print_config(char *config_param, int argc, char **argv)
 	int error_code;
 	slurm_ctl_conf_info_msg_t  *slurm_ctl_conf_ptr = NULL;
 
+	/*
+	 * There isn't a parser for slurm.conf but there is one for ping, which
+	 * gets printed as part of this funciton. So to make sure the ouput is
+	 * not mixing output types disable json/yaml ouput for ping.
+	 */
+	mime_type = NULL;
+
 	if (old_slurm_ctl_conf_ptr) {
 		error_code = slurm_load_ctl_conf (
 				old_slurm_ctl_conf_ptr->last_update,
 				&slurm_ctl_conf_ptr);
 		if (error_code == SLURM_SUCCESS)
 			slurm_free_ctl_conf(old_slurm_ctl_conf_ptr);
-		else if (slurm_get_errno () == SLURM_NO_CHANGE_IN_DATA) {
+		else if (errno == SLURM_NO_CHANGE_IN_DATA) {
 			slurm_ctl_conf_ptr = old_slurm_ctl_conf_ptr;
 			error_code = SLURM_SUCCESS;
 			if (quiet_flag == -1) {
@@ -1642,8 +1657,25 @@ static int _process_command (int argc, char **argv)
 				 "too many arguments for keyword:%s\n",
 				 tag);
 		} else {
-			scontrol_list_pids (argc == 1 ? NULL : argv[1],
-					    argc <= 2 ? NULL : argv[2]);
+			scontrol_list_pids(argc, argv);
+		}
+	} else if (!xstrncasecmp(tag, "listjobs", MAX(tag_len, 1))) {
+		if (argc > 2) {
+			exit_code = 1;
+			fprintf(stderr,
+				"too many arguments for keyword:%s\n",
+				tag);
+		} else {
+			scontrol_list_jobs(argc, argv);
+		}
+	} else if (!xstrncasecmp(tag, "liststeps", MAX(tag_len, 1))) {
+		if (argc > 2) {
+			exit_code = 1;
+			fprintf(stderr,
+				"too many arguments for keyword:%s\n",
+				tag);
+		} else {
+			scontrol_list_steps(argc, argv);
 		}
 	} else if (!xstrncasecmp(tag, "getent", MAX(tag_len, 6))) {
 		scontrol_getent(argc == 1 ? NULL : argv[1]);
@@ -2023,7 +2055,8 @@ static void _update_it(int argc, char **argv)
 
 	if (error_code) {
 		exit_code = 1;
-		slurm_perror ("slurm_update error");
+		if (errno)
+			slurm_perror ("slurm_update error");
 	}
 	/* The slurm error message is already
 	 * printed for each array task in
