@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  crontab.c
  *****************************************************************************
- *  Copyright (C) 2020 SchedMD LLC.
- *  Written by Tim Wickberg <tim@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -58,7 +57,7 @@ typedef struct {
 	identity_t *id;
 	char **job_submit_user_msg;
 	char **failed_lines;
-	List new_jobs;
+	list_t *new_jobs;
 	uint16_t protocol_version;
 	int return_code;
 } foreach_cron_job_args_t;
@@ -176,11 +175,11 @@ static int _clear_requeue_cron(void *x, void *y)
 	if ((job_ptr->user_id == *uid) &&
 	    (job_ptr->bit_flags & CRON_JOB)) {
 		job_ptr->bit_flags &= ~CRON_JOB;
-		job_ptr->job_state &= ~JOB_REQUEUE;
+		job_state_unset_flag(job_ptr, JOB_REQUEUE);
 
 		if (!IS_JOB_RUNNING(job_ptr)) {
 			time_t now = time(NULL);
-			job_ptr->job_state = JOB_CANCELLED;
+			job_state_set(job_ptr, JOB_CANCELLED);
 			job_ptr->start_time = now;
 			job_ptr->end_time = now;
 			job_ptr->exit_code = 1;
@@ -331,5 +330,4 @@ rwfail:
 	close(fd);
 	xfree(file);
 	xfree(lines);
-	return;
 }
