@@ -52,25 +52,49 @@ typedef struct {
 	slurmctld_lock_t locks;
 
 	/* Queue structual elements */
-	char *msg_name; /* automatically derived from msg_type */
+	const char *msg_name; /* automatically derived from msg_type */
 
+	bool skip_stale; /* skip processing if connection is stale */
 	bool queue_enabled;
+	bool hard_drop; /* discard traffic if max_queued exceeded */
 	bool shutdown;
+	bool keep_msg; /* skip freeing msg and closing connection */
+
+	int yield_sleep; /* usec sleep between cycles when busy */
+	int interval; /* usec sleep after cycle if no longer busy */
+
+	uint16_t max_queued;
+	uint16_t max_per_cycle;
+	uint32_t max_usec_per_cycle;
 
 	pthread_t thread;
 	pthread_cond_t cond;
 	pthread_mutex_t mutex;
 
-	List work;
+	list_t *work;
+
+	/* Queue processing statistics */
+	uint16_t queued;
+	uint64_t dropped;
+	uint16_t cycle_last;
+	uint16_t cycle_max;
 } slurmctld_rpc_t;
 
 extern slurmctld_rpc_t slurmctld_rpcs[];
 
+/*
+ * Find RPC matching msg_type in slurmctld_rpcs[].
+ * IN msg_type - RPC type - see slurm_msg_type_t
+ * RET ptr or NULL if not found
+ */
+extern slurmctld_rpc_t *find_rpc(uint16_t msg_type);
+
 /*
  * slurmctld_req  - Process an individual RPC request
  * IN/OUT msg - the request message, data associated with the message is freed
+ * IN this_rpc - pointer to the rpc management structure
  */
-void slurmctld_req(slurm_msg_t *msg);
+extern void slurmctld_req(slurm_msg_t *msg, slurmctld_rpc_t *this_rpc);
 
 /*
  * Update slurmctld stats structure with time spent processing an rpc.
@@ -78,11 +102,9 @@ void slurmctld_req(slurm_msg_t *msg);
 extern void record_rpc_stats(slurm_msg_t *msg, long delta);
 
 /*
- * Initialize a response slurm_msg_t to an inbound msg,
- * first by calling slurm_msg_t_init(), then by copying
- * fields needed to communicate with the remote correctly.
+ * Update slurmctld stats structure related to a particular rpc_queue
  */
-extern void response_init(slurm_msg_t *resp, slurm_msg_t *msg);
+extern void record_rpc_queue_stats(slurmctld_rpc_t *q);
 
 /* Copy an array of type char **, xmalloc() the array and xstrdup() the
  * strings in the array */
@@ -98,4 +120,10 @@ extern char **xduparray(uint32_t size, char ** array);
 extern resource_allocation_response_msg_t *build_alloc_msg(
 	job_record_t *job_ptr, int error_code, char *job_submit_user_msg);
 
+/*
+ * srun_allocate - notify srun of a resource allocation
+ * IN job_ptr - job allocated resources
+ */
+extern void srun_allocate(job_record_t *job_ptr);
+
 #endif /* !_HAVE_PROC_REQ_H */
