@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  rate_limit.c
  *****************************************************************************
- *  Copyright (C) 2023 SchedMD LLC.
- *  Written by Tim Wickberg <tim@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -98,7 +97,10 @@ extern void rate_limit_init(void)
 
 extern void rate_limit_shutdown(void)
 {
+	slurm_mutex_lock(&rate_limit_mutex);
+	rate_limit_enabled = false;
 	xfree(user_buckets);
+	slurm_mutex_unlock(&rate_limit_mutex);
 }
 
 /*
@@ -123,6 +125,11 @@ extern bool rate_limit_exceeded(slurm_msg_t *msg)
 		return false;
 
 	slurm_mutex_lock(&rate_limit_mutex);
+	/* This can happen if we already executed rate_limit_shutdown */
+	if (!user_buckets) {
+		slurm_mutex_unlock(&rate_limit_mutex);
+		return true;
+	}
 	now = time(NULL);
 
 	/*
@@ -181,11 +188,13 @@ extern bool rate_limit_exceeded(slurm_msg_t *msg)
 
 	if (exceeded && (log_freq != -1) &&
 	    ((user_buckets[position].last_logged + log_freq) <= now)) {
-		slurm_addr_t cli_addr;
-		(void) slurm_get_peer_addr(msg->conn_fd, &cli_addr);
+		slurm_addr_t *cli_addr = &msg->address;
+
+		if ((cli_addr->ss_family == AF_UNSPEC) && (msg->conn_fd >= 0))
+			(void) slurm_get_peer_addr(msg->conn_fd, cli_addr);
 
 		info("RPC rate limit exceeded by uid %u with %s from %pA, telling to back off",
-		      msg->auth_uid, rpc_num2string(msg->msg_type), &cli_addr);
+		     msg->auth_uid, rpc_num2string(msg->msg_type), cli_addr);
 		user_buckets[position].last_logged = now;
 	}
 
