@@ -56,6 +56,7 @@
 #include "src/common/hostlist.h"
 #include "src/common/list.h"
 #include "src/common/macros.h"
+#include "src/common/node_features.h"
 #include "src/common/port_mgr.h"
 #include "src/common/read_config.h"
 #include "src/common/slurm_rlimits_info.h"
@@ -95,21 +96,13 @@
 #include "src/stepmgr/srun_comm.h"
 #include "src/stepmgr/stepmgr.h"
 
-#define FEATURE_MAGIC	0x34dfd8b5
-
 /* Global variables */
-bool node_features_updated = true;
 bool slurmctld_init_db = true;
 
 static void _acct_restore_active_jobs(void);
-static void _add_config_feature(list_t *feature_list, char *feature,
-				bitstr_t *node_bitmap);
-static void _add_config_feature_inx(list_t *feature_list, char *feature,
-				    int node_inx);
 static void _build_bitmaps(void);
 static void _gres_reconfig(void);
 static void _init_all_slurm_conf(void);
-static void _list_delete_feature(void *feature_entry);
 static int _preserve_select_type_param(slurm_conf_t *ctl_conf_ptr,
                                        uint16_t old_select_type_p);
 static int  _reset_node_bitmaps(void *x, void *arg);
@@ -1636,9 +1629,9 @@ extern int read_slurm_conf(int recover)
 
 	/* Active and available features can be different on -R */
 	if ((node_features_g_count() == 0) && (recover != 2))
-		build_feature_list_eq();
+		node_features_build_list_eq();
 	else
-		build_feature_list_ne();
+		node_features_build_list_ne();
 
 	_sync_part_prio();
 	_build_part_bitmaps(); /* Must be called after build_feature_list_*() */
@@ -1805,229 +1798,6 @@ end_it:
 
 }
 
-/* Add feature to list
- * feature_list IN - destination list, either active_feature_list or
- *	avail_feature_list
- * feature IN - name of the feature to add
- * node_bitmap IN - bitmap of nodes with named feature */
-static void _add_config_feature(list_t *feature_list, char *feature,
-				bitstr_t *node_bitmap)
-{
-	node_feature_t *feature_ptr;
-	list_itr_t *feature_iter;
-	bool match = false;
-
-	/* If feature already in avail_feature_list, just update the bitmap */
-	feature_iter = list_iterator_create(feature_list);
-	while ((feature_ptr = list_next(feature_iter))) {
-		if (xstrcmp(feature, feature_ptr->name))
-			continue;
-		bit_or(feature_ptr->node_bitmap, node_bitmap);
-		match = true;
-		break;
-	}
-	list_iterator_destroy(feature_iter);
-
-	if (!match) {	/* Need to create new avail_feature_list record */
-		feature_ptr = xmalloc(sizeof(node_feature_t));
-		feature_ptr->magic = FEATURE_MAGIC;
-		feature_ptr->name = xstrdup(feature);
-		feature_ptr->node_bitmap = bit_copy(node_bitmap);
-		list_append(feature_list, feature_ptr);
-	}
-}
-
-/* Add feature to list
- * feature_list IN - destination list, either active_feature_list or
- *	avail_feature_list
- * feature IN - name of the feature to add
- * node_inx IN - index of the node with named feature */
-static void _add_config_feature_inx(list_t *feature_list, char *feature,
-				    int node_inx)
-{
-	node_feature_t *feature_ptr;
-	list_itr_t *feature_iter;
-	bool match = false;
-
-	/* If feature already in avail_feature_list, just update the bitmap */
-	feature_iter = list_iterator_create(feature_list);
-	while ((feature_ptr = list_next(feature_iter))) {
-		if (xstrcmp(feature, feature_ptr->name))
-			continue;
-		bit_set(feature_ptr->node_bitmap, node_inx);
-		match = true;
-		break;
-	}
-	list_iterator_destroy(feature_iter);
-
-	if (!match) {	/* Need to create new avail_feature_list record */
-		feature_ptr = xmalloc(sizeof(node_feature_t));
-		feature_ptr->magic = FEATURE_MAGIC;
-		feature_ptr->name = xstrdup(feature);
-		feature_ptr->node_bitmap = bit_alloc(node_record_count);
-		bit_set(feature_ptr->node_bitmap, node_inx);
-		list_append(feature_list, feature_ptr);
-	}
-}
-
-/* _list_delete_feature - delete an entry from the feature list,
- *	see list.h for documentation */
-static void _list_delete_feature(void *feature_entry)
-{
-	node_feature_t *feature_ptr = feature_entry;
-
-	xassert(feature_ptr);
-	xassert(feature_ptr->magic == FEATURE_MAGIC);
-	xfree (feature_ptr->name);
-	FREE_NULL_BITMAP (feature_ptr->node_bitmap);
-	xfree (feature_ptr);
-}
-
-/*
- * For a configuration where available_features == active_features,
- * build new active and available feature lists
- */
-extern void build_feature_list_eq(void)
-{
-	list_itr_t *config_iterator;
-	config_record_t *config_ptr;
-	node_feature_t *active_feature_ptr, *avail_feature_ptr;
-	list_itr_t *feature_iter;
-	char *tmp_str, *token, *last = NULL;
-
-	FREE_NULL_LIST(active_feature_list);
-	FREE_NULL_LIST(avail_feature_list);
-	active_feature_list = list_create(_list_delete_feature);
-	avail_feature_list = list_create(_list_delete_feature);
-
-	config_iterator = list_iterator_create(config_list);
-	while ((config_ptr = list_next(config_iterator))) {
-		if (config_ptr->feature) {
-			tmp_str = xstrdup(config_ptr->feature);
-			token = strtok_r(tmp_str, ",", &last);
-			while (token) {
-				_add_config_feature(avail_feature_list, token,
-						    config_ptr->node_bitmap);
-				token = strtok_r(NULL, ",", &last);
-			}
-			xfree(tmp_str);
-		}
-	}
-	list_iterator_destroy(config_iterator);
-
-	/* Copy avail_feature_list to active_feature_list */
-	feature_iter = list_iterator_create(avail_feature_list);
-	while ((avail_feature_ptr = list_next(feature_iter))) {
-		active_feature_ptr = xmalloc(sizeof(node_feature_t));
-		active_feature_ptr->magic = FEATURE_MAGIC;
-		active_feature_ptr->name = xstrdup(avail_feature_ptr->name);
-		active_feature_ptr->node_bitmap =
-			bit_copy(avail_feature_ptr->node_bitmap);
-		list_append(active_feature_list, active_feature_ptr);
-	}
-	list_iterator_destroy(feature_iter);
-}
-
-/*
- * Log contents of avail_feature_list and active_feature_list
- */
-extern void log_feature_lists(void)
-{
-	node_feature_t *feature_ptr;
-	char *node_str;
-	list_itr_t *feature_iter;
-
-	feature_iter = list_iterator_create(avail_feature_list);
-	while ((feature_ptr = list_next(feature_iter))) {
-		node_str = bitmap2node_name(feature_ptr->node_bitmap);
-		info("AVAIL FEATURE:%s NODES:%s", feature_ptr->name, node_str);
-		xfree(node_str);
-	}
-	list_iterator_destroy(feature_iter);
-
-	feature_iter = list_iterator_create(active_feature_list);
-	while ((feature_ptr = list_next(feature_iter))) {
-		node_str = bitmap2node_name(feature_ptr->node_bitmap);
-		info("ACTIVE FEATURE:%s NODES:%s", feature_ptr->name, node_str);
-		xfree(node_str);
-	}
-	list_iterator_destroy(feature_iter);
-}
-
-/*
- * For a configuration where available_features != active_features,
- * build new active and available feature lists
- */
-extern void build_feature_list_ne(void)
-{
-	node_record_t *node_ptr;
-	char *tmp_str, *token, *last = NULL;
-	int i;
-
-	FREE_NULL_LIST(active_feature_list);
-	FREE_NULL_LIST(avail_feature_list);
-	active_feature_list = list_create(_list_delete_feature);
-	avail_feature_list = list_create(_list_delete_feature);
-
-	for (i = 0; (node_ptr = next_node(&i)); i++) {
-		if (node_ptr->features_act) {
-			tmp_str = xstrdup(node_ptr->features_act);
-			token = strtok_r(tmp_str, ",", &last);
-			while (token) {
-				_add_config_feature_inx(active_feature_list,
-							token, node_ptr->index);
-				token = strtok_r(NULL, ",", &last);
-			}
-			xfree(tmp_str);
-		}
-		if (node_ptr->features) {
-			tmp_str = xstrdup(node_ptr->features);
-			token = strtok_r(tmp_str, ",", &last);
-			while (token) {
-				_add_config_feature_inx(avail_feature_list,
-							token, node_ptr->index);
-				token = strtok_r(NULL, ",", &last);
-			}
-			xfree(tmp_str);
-		}
-	}
-}
-
-/*
- * Update active_feature_list or avail_feature_list
- * feature_list IN - list to update: active_feature_list or avail_feature_list
- * new_features IN - New active_features
- * node_bitmap IN - Nodes with the new active_features value
- */
-extern void update_feature_list(list_t *feature_list, char *new_features,
-				bitstr_t *node_bitmap)
-{
-	node_feature_t *feature_ptr;
-	list_itr_t *feature_iter;
-	char *tmp_str, *token, *last = NULL;
-
-	/*
-	 * Clear these nodes from the feature_list record,
-	 * then restore as needed
-	 */
-	feature_iter = list_iterator_create(feature_list);
-	while ((feature_ptr = list_next(feature_iter))) {
-		bit_and_not(feature_ptr->node_bitmap, node_bitmap);
-	}
-	list_iterator_destroy(feature_iter);
-
-	if (new_features) {
-		tmp_str = xstrdup(new_features);
-		token = strtok_r(tmp_str, ",", &last);
-		while (token) {
-			_add_config_feature(feature_list, token, node_bitmap);
-			token = strtok_r(NULL, ",", &last);
-		}
-		xfree(tmp_str);
-	}
-	node_features_updated = true;
-}
-
 static void _gres_reconfig(void)
 {
 	node_record_t *node_ptr;
