@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  container.c - slurmstepd container handling
  *****************************************************************************
- *  Copyright (C) 2021 SchedMD LLC.
- *  Written by Nathan Rini <nate@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -1005,15 +1004,12 @@ static void _create_start(stepd_step_rec_t *step,
 static void _generate_patterns(stepd_step_rec_t *step,
 			       stepd_step_task_info_t *task)
 {
-	static bool generated = false;
 	char *gen;
 	int id = -1;
 	char **argv = NULL;
 
-	if (generated)
-		return;
-
-	generated = true;
+	debug2("%s: %ps TaskId=%d",
+	       __func__, &step->step_id, (task ? task->id : -1));
 
 	if (task) {
 		id = task->id;
@@ -1021,29 +1017,58 @@ static void _generate_patterns(stepd_step_rec_t *step,
 	}
 
 	gen = _generate_pattern(oci_conf->runtime_create, step, id, argv);
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(create_argv[2]);
 		create_argv[2] = gen;
+		set = true;
+	}
 
 	gen = _generate_pattern(oci_conf->runtime_delete, step, id, argv);
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(delete_argv[2]);
 		delete_argv[2] = gen;
+		set = true;
+	}
 
 	gen = _generate_pattern(oci_conf->runtime_kill, step, id, argv);
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(kill_argv[2]);
 		kill_argv[2] = gen;
+		set = true;
+	}
 
 	gen = _generate_pattern(oci_conf->runtime_query, step, id, argv);
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(query_argv[2]);
 		query_argv[2] = gen;
+		set = true;
+	}
 
 	gen = _generate_pattern(oci_conf->runtime_run, step, id, argv);
-
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(run_argv[2]);
 		run_argv[2] = gen;
+		set = true;
+	}
 
 	gen = _generate_pattern(oci_conf->runtime_start, step, id, argv);
-	if (gen)
+	if (gen) {
+		static bool set = false;
+		if (set)
+			xfree(start_argv[2]);
 		start_argv[2] = gen;
+		set = true;
+	}
 }
 
 extern void container_run(stepd_step_rec_t *step,
@@ -1170,6 +1195,7 @@ extern void cleanup_container(stepd_step_rec_t *step)
 
 	/* cleanup may be called without ever setting up container */
 
+	_generate_patterns(step, NULL);
 	_kill_container();
 
 	if (oci_conf->disable_cleanup)
