@@ -73,7 +73,6 @@
 #include "src/common/spank.h"
 #include "src/common/strlcpy.h"
 #include "src/common/xmalloc.h"
-#include "src/common/xsignal.h"
 #include "src/common/xstring.h"
 
 #include "src/interfaces/auth.h"
@@ -136,16 +135,6 @@ static void _proc_stdout(char *buf, stepd_step_rec_t *step)
 				equal_ptr--;
 			equal_ptr[0] = '\0';
 			end_line[0] = '\0';
-			if (!xstrcmp(name_ptr, "SLURM_PROLOG_CPU_MASK")) {
-				step->cpu_bind_type = CPU_BIND_MASK;
-				xfree(step->cpu_bind);
-				step->cpu_bind = xstrdup(val_ptr);
-				if (task_g_pre_launch(step)) {
-					error("Failed SLURM_PROLOG_CPU_MASK "
-					      "setup");
-					exit(1);
-				}
-			}
 			debug("export name:%s:val:%s:", name_ptr, val_ptr);
 			if (setenvf(env, name_ptr, "%s", val_ptr)) {
 				error("Unable to set %s environment variable",
@@ -368,6 +357,7 @@ extern void exec_task(stepd_step_rec_t *step, int local_proc_id)
 	step->envtp->job_licenses = xstrdup(step->job_licenses);
 	step->envtp->job_start_time = step->job_start_time;
 	step->envtp->user_name = xstrdup(step->user_name);
+	step->envtp->oom_kill_step = step->oom_kill_step ? 1 : 0;
 
 	/*
 	 * Modify copy of step's environment. Do not alter in place or
@@ -541,12 +531,12 @@ extern void exec_task(stepd_step_rec_t *step, int local_proc_id)
 			eol = strchr(buf, '\n');
 			if (eol)
 				eol[0] = '\0';
-			slurm_seterrno(saved_errno);
+			errno = saved_errno;
 			error("execve(): bad interpreter(%s): %m", buf+2);
 			_exit(errno);
 		}
 	}
-	slurm_seterrno(saved_errno);
+	errno = saved_errno;
 	error("execve(): %s: %m", task->argv[0]);
 	_exit(errno);
 }
