@@ -1,8 +1,7 @@
 /*****************************************************************************\
  *  jobs.c - Slurm REST API jobs http operations handlers
  *****************************************************************************
- *  Copyright (C) 2019-2020 SchedMD LLC.
- *  Written by Nathan Rini <nate@schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *
  *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
@@ -51,6 +50,14 @@
 
 #include "api.h"
 
+#define FOREACH_ALLOC_JOB_ARGS_MAGIC 0x1f133335
+typedef struct {
+	int magic; /* FOREACH_ALLOC_JOB_ARGS_MAGIC */
+	ctxt_t *ctxt;
+	openapi_job_alloc_response_t *oas_resp;
+	int component; /* index or NO_VAL */
+} foreach_alloc_job_args_t;
+
 /* list from job_allocate() */
 static const slurm_err_t nonfatal_errors[] = {
 	ESLURM_NODES_BUSY,
@@ -64,6 +71,7 @@ static const slurm_err_t nonfatal_errors[] = {
 	ESLURM_BURST_BUFFER_WAIT,
 	ESLURM_PARTITION_DOWN,
 	ESLURM_LICENSES_UNAVAILABLE,
+	ESLURM_PORTS_BUSY,
 };
 
 static int _signal_jobs(openapi_ctxt_t *ctxt)
@@ -93,7 +101,7 @@ static int _signal_jobs(openapi_ctxt_t *ctxt)
 	return rc;
 }
 
-static int _op_handler_jobs(openapi_ctxt_t *ctxt)
+extern int op_handler_jobs(openapi_ctxt_t *ctxt)
 {
 	openapi_job_info_query_t query = {0};
 	job_info_msg_t *job_info_ptr = NULL;
@@ -130,6 +138,8 @@ static int _op_handler_jobs(openapi_ctxt_t *ctxt)
 			  "No job changes since update_time[%ld]=%s",
 			  query.update_time, ts);
 	} else if (rc) {
+		if ((rc == SLURM_ERROR) && errno)
+			rc = errno;
 		resp_error(ctxt, rc, "slurm_load_jobs()",
 			   "Unable to query jobs");
 	} else if (job_info_ptr) {
@@ -194,33 +204,66 @@ static void _handle_job_get(ctxt_t *ctxt, slurm_selected_step_t *job_id)
 	slurm_free_job_info_msg(job_info_ptr);
 }
 
-static void _handle_job_delete(ctxt_t *ctxt, slurm_selected_step_t *job_id)
+static int _parse_job_delete(ctxt_t *ctxt, slurm_selected_step_t *job_id,
+			     kill_jobs_msg_t *req)
 {
 	openapi_job_info_delete_query_t query = {0};
+	int rc;
 
-	if (DATA_PARSE(ctxt->parser, OPENAPI_JOB_INFO_DELETE_QUERY, query,
-		       ctxt->query, ctxt->parent_path))
-		return;
+	if ((rc = DATA_PARSE(ctxt->parser, OPENAPI_JOB_INFO_DELETE_QUERY, query,
+			     ctxt->query, ctxt->parent_path)))
+		return rc;
 
-	if (!query.signal)
-		query.signal = SIGKILL;
+	if (!(req->flags = query.flags))
+		req->flags = KILL_FULL_JOB;
 
-	if (!query.flags)
-		query.flags = KILL_FULL_JOB;
+	if (!(req->signal = query.signal))
+		req->signal = SIGKILL;
 
-	if (slurm_kill_job(job_id->step_id.job_id, query.signal, query.flags)) {
-		/* Already signaled jobs are considered a success here */
-		if (errno == ESLURM_ALREADY_DONE) {
-			resp_warn(ctxt, __func__,
-				  "Job was already sent signal %s",
-				  strsignal(query.signal));
-			return;
-		}
+	req->jobs_array = xcalloc(2, sizeof(*req->jobs_array));
+	req->jobs_cnt = 1;
 
-		resp_error(ctxt, errno, "slurm_kill_job2()",
-			   "unable to send signal %s to JobId=%u",
-			   strsignal(query.signal), job_id->step_id.job_id);
+	return fmt_job_id_string(job_id, &req->jobs_array[0]);
+}
+
+static int _signal_job(ctxt_t *ctxt, kill_jobs_msg_t *req,
+		       kill_jobs_resp_msg_t **resp_ptr)
+{
+	int rc;
+
+	if (!(rc = slurm_kill_jobs(req, resp_ptr))) {
+		if ((req->flags & KILL_JOBS_VERBOSE) && !(*resp_ptr)->jobs_cnt)
+			resp_warn(ctxt, __func__, "Zero jobs sent signal %s",
+				  strsignal(req->signal));
+		return rc;
 	}
+
+	/* Already signaled jobs are considered a success */
+	if (rc == ESLURM_ALREADY_DONE) {
+		resp_warn(ctxt, __func__, "Job was already sent signal %s",
+			  strsignal(req->signal));
+		return SLURM_SUCCESS;
+	}
+
+	resp_error(ctxt, rc, "slurm_kill_jobs()", "Signal request failed");
+	return rc;
+}
+
+static void _handle_job_delete(ctxt_t *ctxt, slurm_selected_step_t *job_id)
+{
+	int rc;
+	kill_jobs_resp_msg_t *resp = NULL;
+	kill_jobs_msg_t *req = xmalloc(sizeof(*req));
+
+	*req = (kill_jobs_msg_t) KILL_JOB_MSG_INITIALIZER;
+
+	if (!(rc = _parse_job_delete(ctxt, job_id, req)))
+		rc = _signal_job(ctxt, req, &resp);
+
+	DUMP_OPENAPI_RESP_SINGLE(OPENAPI_KILL_JOB_RESP, resp, ctxt);
+
+	slurm_free_kill_jobs_msg(req);
+	slurm_free_kill_jobs_response_msg(resp);
 }
 
 static void _job_post_update(ctxt_t *ctxt, slurm_selected_step_t *job_id)
@@ -422,28 +465,28 @@ static void _job_post(ctxt_t *ctxt)
 	if (!ctxt->query) {
 		resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
 			   "unexpected empty query for job");
-		return;
+		goto cleanup;
 	}
 
 	if (DATA_PARSE(ctxt->parser, JOB_SUBMIT_REQ, req, ctxt->query,
 		       ctxt->parent_path))
-		return;
+		goto cleanup;
 
 	if (!req.jobs && (!req.script || !req.script[0]) &&
 	    (!req.job || !req.job->script)) {
 		resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
 			   "Populated \"script\" field is required for job submission");
-		return;
+		goto cleanup;
 	}
 	if (req.job && req.jobs) {
 		resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
 			   "Specify only one \"job\" or \"jobs\" fields but never both");
-		return;
+		goto cleanup;
 	}
 	if (!req.job && !req.jobs) {
 		resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
 			   "Specifing either \"job\" or \"jobs\" fields are required to submit job");
-		return;
+		goto cleanup;
 	}
 
 	if (req.job) {
@@ -452,12 +495,13 @@ static void _job_post(ctxt_t *ctxt)
 		_job_post_het_submit(ctxt, req.jobs, req.script);
 	}
 
+cleanup:
 	slurm_free_job_desc_msg(req.job);
 	FREE_NULL_LIST(req.jobs);
 	xfree(req.script);
 }
 
-static int _op_handler_job(openapi_ctxt_t *ctxt)
+extern int op_handler_job(openapi_ctxt_t *ctxt)
 {
 	openapi_job_info_param_t params = {{ 0 }};
 	slurm_selected_step_t *job_id;
@@ -494,7 +538,7 @@ static int _op_handler_job(openapi_ctxt_t *ctxt)
 	return SLURM_SUCCESS;
 }
 
-static int _op_handler_submit_job(openapi_ctxt_t *ctxt)
+extern int op_handler_submit_job(openapi_ctxt_t *ctxt)
 {
 	if (ctxt->method == HTTP_REQUEST_POST) {
 		_job_post(ctxt);
@@ -507,7 +551,201 @@ static int _op_handler_submit_job(openapi_ctxt_t *ctxt)
 	return ctxt->rc;
 }
 
-static int _op_handler_job_states(openapi_ctxt_t *ctxt)
+static void _job_alloc_rc(ctxt_t *ctxt,
+			  resource_allocation_response_msg_t *resp,
+			  const char *src)
+{
+	int rc;
+
+	if (!resp || !(rc = resp->error_code))
+		return;
+
+	for (int i = 0; i < ARRAY_SIZE(nonfatal_errors); i++) {
+		if (rc == nonfatal_errors[i]) {
+			resp_warn(ctxt, "slurm_submit_batch_job()",
+				"%s", slurm_strerror(rc));
+			return;
+		}
+	}
+
+	resp_error(ctxt, rc, src, NULL);
+}
+
+static int _foreach_alloc_job(void *x, void *arg)
+{
+	job_desc_msg_t *job = x;
+	xassert(!arg);
+
+	/* Force user/group to be determined by auth */
+	job->user_id = SLURM_AUTH_NOBODY;
+	job->group_id = SLURM_AUTH_NOBODY;
+
+	/* Force disable status updates */
+	job->other_port = 0;
+
+	/* force atleast 1 node for job */
+	if (!job->min_nodes || (job->min_nodes >= NO_VAL))
+		job->min_nodes = 1;
+
+	return SLURM_SUCCESS;
+}
+
+static int _foreach_alloc_job_resp(void *x, void *arg)
+{
+	resource_allocation_response_msg_t *resp = x;
+	foreach_alloc_job_args_t *args = arg;
+	openapi_job_alloc_response_t *oas_resp = args->oas_resp;
+	ctxt_t *ctxt = args->ctxt;
+
+	xassert(args->magic == FOREACH_ALLOC_JOB_ARGS_MAGIC);
+
+	xassert(!oas_resp->job_id || (oas_resp->job_id == resp->job_id) ||
+		(oas_resp->job_id == (resp->job_id - args->component)));
+	oas_resp->job_id = resp->job_id;
+
+	if (!oas_resp->job_submit_user_msg)
+		oas_resp->job_submit_user_msg = resp->job_submit_user_msg;
+
+	if (args->component == NO_VAL) {
+		debug3("%s:[%s] Job submitted -> JobId=%d rc:%d message:%s",
+		       __func__, ctxt->id, resp->job_id,
+		       resp->error_code, resp->job_submit_user_msg);
+	} else {
+		debug3("%s:[%s] HetJob submitted -> JobId=%d+%d rc:%d message:%s",
+		       __func__, ctxt->id, resp->job_id, args->component,
+		       resp->error_code, resp->job_submit_user_msg);
+		args->component++;
+	}
+
+	_job_alloc_rc(ctxt, resp,
+		      "slurm_allocate_resources_blocking()");
+
+	return SLURM_SUCCESS;
+}
+
+static void _job_post_allocate(ctxt_t *ctxt, job_desc_msg_t *job)
+{
+	resource_allocation_response_msg_t *resp = NULL;
+
+	(void) _foreach_alloc_job(job, NULL);
+
+	if (!(resp = slurm_allocate_resources_blocking(job, 0, NULL))) {
+		resp_error(ctxt, errno, "slurm_allocate_resources_blocking()",
+			   "Job allocation request failed");
+	} else {
+		openapi_job_alloc_response_t oas_resp = {0};
+		foreach_alloc_job_args_t args = {
+			.magic = FOREACH_ALLOC_JOB_ARGS_MAGIC,
+			.ctxt = ctxt,
+			.oas_resp = &oas_resp,
+			.component = NO_VAL,
+		};
+
+		(void) _foreach_alloc_job_resp(resp, &args);
+
+		DATA_DUMP(ctxt->parser, OPENAPI_JOB_ALLOC_RESP, oas_resp,
+			  ctxt->resp);
+	}
+
+	slurm_free_resource_allocation_response_msg(resp);
+}
+
+static void _job_post_het_allocate(ctxt_t *ctxt, list_t *hetjob)
+{
+	list_t *resp = NULL;
+
+	if (!hetjob || !list_count(hetjob)) {
+		resp_error(ctxt, errno, __func__,
+			   "Refusing HetJob submission without any components");
+		goto cleanup;
+	}
+
+	if (list_count(hetjob) > MAX_HET_JOB_COMPONENTS) {
+		resp_error(ctxt, errno, __func__,
+			   "Refusing HetJob submission too many components: %d > %u",
+			   list_count(hetjob), MAX_HET_JOB_COMPONENTS);
+		goto cleanup;
+	}
+
+	(void) list_for_each(hetjob, _foreach_alloc_job, NULL);
+
+	if (!(resp = slurm_allocate_het_job_blocking(hetjob, 0, NULL))) {
+		resp_error(ctxt, errno, "slurm_allocate_het_job_blocking()",
+			   "Job allocation request failed");
+	} else {
+		openapi_job_alloc_response_t oas_resp = {0};
+		foreach_alloc_job_args_t args = {
+			.magic = FOREACH_ALLOC_JOB_ARGS_MAGIC,
+			.ctxt = ctxt,
+			.oas_resp = &oas_resp,
+			.component = 0,
+		};
+
+		(void) list_for_each(resp, _foreach_alloc_job_resp, &args);
+
+		DATA_DUMP(ctxt->parser, OPENAPI_JOB_ALLOC_RESP, oas_resp,
+			  ctxt->resp);
+	}
+
+cleanup:
+	FREE_NULL_LIST(resp);
+}
+
+extern int op_handler_alloc_job(openapi_ctxt_t *ctxt)
+{
+	int rc = SLURM_SUCCESS;
+	openapi_job_alloc_request_t req = {0};
+
+	if (ctxt->method != HTTP_REQUEST_POST)
+		return resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
+				  "Unsupported HTTP method requested: %s",
+				  get_http_method_string(ctxt->method));
+
+	if ((slurm_conf.debug_flags & DEBUG_FLAG_NET_RAW) && ctxt->query) {
+		char *buffer = NULL;
+
+		serialize_g_data_to_string(&buffer, NULL, ctxt->query,
+					   MIME_TYPE_JSON, SER_FLAGS_COMPACT);
+
+		log_flag(NET_RAW, "%s:[%s] alloc job POST: %s",
+		       __func__, ctxt->id, buffer);
+
+		xfree(buffer);
+	}
+
+	if (!ctxt->query) {
+		return resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
+				  "unexpected empty query for job");
+	}
+
+	if ((rc = DATA_PARSE(ctxt->parser, JOB_ALLOC_REQ, req, ctxt->query,
+		       ctxt->parent_path)))
+		goto cleanup;
+
+	if (req.job && req.hetjob) {
+		rc = resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
+				"Specify only one \"job\" or \"hetjob\" fields but never both");
+		goto cleanup;
+	}
+	if (!req.job && !req.hetjob) {
+		rc = resp_error(ctxt, ESLURM_REST_INVALID_QUERY, __func__,
+				"Specifing either \"job\" or \"hetjob\" fields are required to allocate job");
+		goto cleanup;
+	}
+
+	if (req.job)
+		_job_post_allocate(ctxt, req.job);
+	else
+		_job_post_het_allocate(ctxt, req.hetjob);
+
+cleanup:
+	slurm_free_job_desc_msg(req.job);
+	FREE_NULL_LIST(req.hetjob);
+
+	return rc;
+}
+
+extern int op_handler_job_states(openapi_ctxt_t *ctxt)
 {
 	openapi_job_state_query_t query = { 0 };
 	openapi_resp_job_state_t resp = { 0 };
@@ -553,19 +791,3 @@ static int _op_handler_job_states(openapi_ctxt_t *ctxt)
 	xfree(job_ids);
 	return rc;
 }
-
-extern void init_op_jobs(void)
-{
-	bind_handler("/slurm/{data_parser}/job/submit", _op_handler_submit_job);
-	bind_handler("/slurm/{data_parser}/jobs/", _op_handler_jobs);
-	bind_handler("/slurm/{data_parser}/job/{job_id}", _op_handler_job);
-	bind_handler("/slurm/{data_parser}/jobs/state", _op_handler_job_states);
-}
-
-extern void destroy_op_jobs(void)
-{
-	unbind_operation_ctxt_handler(_op_handler_submit_job);
-	unbind_operation_ctxt_handler(_op_handler_job);
-	unbind_operation_ctxt_handler(_op_handler_jobs);
-	unbind_operation_ctxt_handler(_op_handler_job_states);
-}
