@@ -3,7 +3,7 @@
  *****************************************************************************
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
- *  Copyright (C) 2010-2016 SchedMD LLC.
+ *  Copyright (C) SchedMD LLC.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
@@ -215,7 +215,7 @@ static int _set_trigger(void)
 
 	while (slurm_set_trigger(&ti)) {
 		slurm_perror("slurm_set_trigger");
-		if (slurm_get_errno() != EAGAIN)
+		if (errno != EAGAIN)
 			return 1;
 		sleep(5);
 	}
