@@ -3,7 +3,7 @@
  *  mode of sview.
  *****************************************************************************
  *  Copyright (C) 2009-2011 Lawrence Livermore National Security.
- *  Portions Copyright (C) 2012-2015 SchedMD LLC <https://www.schedmd.com>
+ *  Copyright (C) SchedMD LLC.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
@@ -236,7 +236,6 @@ static const char *_set_resv_msg(resv_desc_msg_t *resv_msg,
 				 int column)
 {
 	char *type = "";
-	char *err_msg = NULL;
 	uint32_t res_free_flags = 0;
 	int temp_int = 0;
 	uint64_t f;
@@ -347,19 +346,6 @@ static const char *_set_resv_msg(resv_desc_msg_t *resv_msg,
 		resv_msg->tres_str = xstrdup(new_text);
 		type = "TRES";
 		break;
-	case SORTID_WATTS:
-		resv_msg->resv_watts = slurm_watts_str_to_int(
-			(char *) new_text, &err_msg);
-
-		if (err_msg) {
-			if (global_edit_error_msg)
-				g_free(global_edit_error_msg);
-			global_edit_error_msg = g_strdup(err_msg);
-			xfree(err_msg);
-			goto return_error;
-		}
-		type = "watts";
-		break;
 	default:
 		type = "unknown";
 		break;
@@ -601,13 +587,6 @@ static void _layout_resv_record(GtkTreeView *treeview,
 				   find_col_name(display_data_resv,
 						 SORTID_USERS),
 				   resv_ptr->users);
-
-	temp_char = slurm_watts_to_str(resv_ptr->resv_watts);
-	add_display_treestore_line(update, treestore, &iter,
-				   find_col_name(display_data_resv,
-						 SORTID_WATTS),
-				   temp_char);
-	xfree(temp_char);
 }
 
 static void _update_resv_record(sview_resv_info_t *sview_resv_info_ptr,
@@ -616,7 +595,6 @@ static void _update_resv_record(sview_resv_info_t *sview_resv_info_ptr,
 	char tmp_duration[40], tmp_end[256], tmp_nodes[40], tmp_start[256];
 	char tmp_cores[40], tmp_msd[40];
 	char *tmp_flags;
-	char *tmp_watts = NULL;
 	reserve_info_t *resv_ptr = sview_resv_info_ptr->resv_ptr;
 
 	secs2time_str((uint32_t)difftime(resv_ptr->end_time,
@@ -639,8 +617,6 @@ static void _update_resv_record(sview_resv_info_t *sview_resv_info_ptr,
 	slurm_make_time_str((time_t *)&resv_ptr->start_time, tmp_start,
 			    sizeof(tmp_start));
 
-	tmp_watts = slurm_watts_to_str(resv_ptr->resv_watts);
-
 	if (resv_ptr->max_start_delay)
 		secs2time_str(resv_ptr->max_start_delay,
 			      tmp_msd, sizeof(tmp_msd));
@@ -670,11 +646,9 @@ static void _update_resv_record(sview_resv_info_t *sview_resv_info_ptr,
 			   SORTID_TRES,       resv_ptr->tres_str,
 			   SORTID_UPDATED,    1,
 			   SORTID_USERS,      resv_ptr->users,
-			   SORTID_WATTS,      tmp_watts,
 			   -1);
 
 	xfree(tmp_flags);
-	xfree(tmp_watts);
 
 	return;
 }
